@@ -19,7 +19,6 @@
 
 #include <config.h>
 
-#include <string.h>
 #include <string.h>
 #include <unistd.h>
 #include <time.h>
@@ -33,10 +32,14 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
+#ifdef HAVE_CLUTTER
+#include <clutter/clutter.h>
+#endif
+
 #include "conf.h"
 #include "util.h"
 
-#include <libgames-support/games-files.h>
+#include <libgames-support/games-runtime.h>
 
 #include "game.h"
 
@@ -237,8 +240,17 @@ clear_slots (AisleriotGame *game,
   for (i = 0; i < n_slots; ++i) {
     Slot *slot = game->slots->pdata[i];
 
-    g_byte_array_free (slot->cards, TRUE);
+#ifdef HAVE_CLUTTER
+    if (slot->slot_renderer) {
+      clutter_actor_destroy (slot->slot_renderer);
+      g_object_unref (slot->slot_renderer);
+    }
+
+    g_byte_array_free (slot->old_cards, TRUE);
+#else
     g_ptr_array_free (slot->card_images, TRUE);
+#endif /* HAVE_CLUTTER */
+    g_byte_array_free (slot->cards, TRUE);
 
     g_slice_free (Slot, slot);
   }
@@ -583,7 +595,11 @@ cscmi_add_slot (SCM slot_data)
   slot->expanded_down = expanded_down != FALSE;
   slot->expanded_right = expanded_right != FALSE;
 
+#ifdef HAVE_CLUTTER
+  slot->old_cards = g_byte_array_sized_new (SLOT_CARDS_N_PREALLOC);
+#else
   slot->card_images = g_ptr_array_sized_new (SLOT_CARDS_N_PREALLOC);
+#endif
 
   slot->needs_update = TRUE;
 
@@ -1076,7 +1092,7 @@ cscmi_eval_installed_file (const char *filename,
     return FALSE;
   }
 
-  path = games_build_filename (GAMESDIR, filename);
+  path = games_runtime_get_file (GAMES_RUNTIME_GAME_GAMES_DIRECTORY, filename);
   if (g_file_test (path, G_FILE_TEST_EXISTS) &&
       g_file_test (path, G_FILE_TEST_IS_REGULAR)) {
     scm_c_primitive_load (path);
@@ -1085,7 +1101,7 @@ cscmi_eval_installed_file (const char *filename,
   }
 
   g_set_error (error, AISLERIOT_GAME_ERROR, GAME_ERROR_GENERIC,
-               _("Aisleriot cannot load the file \"%s\". "
+               _("Aisleriot cannot load the file “%s”. "
                  "Please check your Aisleriot installation."),
                path);
   g_free (path);
@@ -2062,3 +2078,41 @@ aisleriot_game_deal_cards (AisleriotGame *game)
   aisleriot_game_end_move (game);
   aisleriot_game_test_end_of_game (game);
 }
+
+#ifdef HAVE_CLUTTER
+
+void
+aisleriot_game_get_card_offset (Slot *slot,
+                                guint card_num,
+                                gboolean old_cards,
+                                gint *xoff, gint *yoff)
+{
+  gint n_cards, exposed;
+
+  if (old_cards) {
+    n_cards = (gint) slot->old_cards->len;
+    exposed = (gint) slot->old_exposed;
+  } else {
+    n_cards = (gint) slot->cards->len;
+    exposed = (gint) slot->exposed;
+  }
+
+  if (card_num >= n_cards - exposed) {
+    gint index = card_num + exposed - n_cards;
+    *xoff = slot->pixeldx * index;
+    *yoff = slot->pixeldy * index;
+  } else {
+    *xoff = 0;
+    *yoff = 0;
+  }
+}
+
+void
+aisleriot_game_reset_old_cards (Slot *slot)
+{
+  g_byte_array_set_size (slot->old_cards, 0);
+  g_byte_array_append (slot->old_cards, slot->cards->data, slot->cards->len);
+  slot->old_exposed = slot->exposed;
+}
+
+#endif /* HAVE_CLUTTER */
