@@ -33,14 +33,9 @@
 
 #include <glib/gi18n.h>
 
+#include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-#ifdef HAVE_GNOME
-#include <libgnomeui/gnome-help.h>
-#else
-#include <gdk/gdkspawn.h>
-#endif
-
 #ifdef HAVE_HILDON
 #ifdef HAVE_MAEMO_3
 #include <hildon-widgets/hildon-banner.h>
@@ -52,6 +47,7 @@
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
 
 #include "board.h"
@@ -217,6 +213,7 @@ select_game_cb (GtkAction *action,
   GtkTreeIter current_iter, selection_iter;
   gboolean current_iter_set = FALSE;
   const char *current_game_file;
+  const char *games_dir;
   GList *l;
 
   if (priv->game_choice_dialog) {
@@ -228,7 +225,8 @@ select_game_cb (GtkAction *action,
   list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
   g_object_unref (list);
 
-  files = games_file_list_new ("*.scm", games_path_runtime_fix (GAMESDIR), NULL);
+  games_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+  files = games_file_list_new ("*.scm", games_dir, NULL);
   games_file_list_transform_basename (files);
 
   current_game_file = aisleriot_game_get_game_file (priv->game);
@@ -610,7 +608,7 @@ help_about_cb (GtkAction *action,
                            NULL :
                            _("AisleRiot provides a rule-based solitaire "
                              "card engine that allows many different "
-                             "games to be played.\n\n"
+                             "games to be played.\n"
 			     "AisleRiot is a part of GNOME Games."),
 #endif
                          "copyright", "Copyright © 1998-2006 Jonathan Blandford\n"
@@ -759,12 +757,14 @@ debug_ensure_game_list (AisleriotWindow *window)
   DebugWindowData *data;
   GamesFileList *files;
   GList *l;
+  const char *games_dir;
 
   data = g_object_get_data (G_OBJECT (window), DEBUG_WINDOW_DATA_KEY);
   if (data != NULL)
     return data;
 
-  files = games_file_list_new ("*.scm", games_path_runtime_fix (GAMESDIR), NULL);
+  games_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+  files = games_file_list_new ("*.scm", games_dir, NULL);
   games_file_list_transform_basename (files);
 
   data = g_slice_new (DebugWindowData);
@@ -1528,7 +1528,7 @@ install_recently_played_menu (AisleriotWindow *window)
 #ifdef HAVE_HILDON
     tooltip = NULL;
 #else
-    tooltip = g_strdup_printf (_("Play \"%s\""), game_name);
+    tooltip = g_strdup_printf (_("Play “%s”"), game_name);
 #endif /* HAVE_HILDON */
     action = gtk_action_new (actionname, game_name, tooltip, NULL);
     g_free (game_name);
@@ -1632,7 +1632,7 @@ install_card_theme_menu (AisleriotWindow *window)
 #ifdef HAVE_HILDON
     tooltip = NULL;
 #else
-    tooltip = g_strdup_printf (_("Display cards with \"%s\" card theme"), display_name);
+    tooltip = g_strdup_printf (_("Display cards with “%s” card theme"), display_name);
 #endif
     action = gtk_radio_action_new (actionname, display_name, tooltip, NULL, i);
     g_free (display_name);
@@ -2723,7 +2723,7 @@ load_idle_cb (LoadIdleData *data)
                                      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR,
                                      GTK_BUTTONS_OK,
-                                     _("Cannot start the game \"%s\""),
+                                     _("Cannot start the game “%s”"),
                                      name);
     g_free (name);
 
