@@ -19,4 +19,7 @@ which gnome-autogen.sh || {
     exit 1
 }
 
-REQUIRED_GNOME_DOC_UTILS_VERSION=0.10.0 REQUIRED_AUTOMAKE_VERSION=1.9 USE_GNOME2_MACROS=1 . gnome-autogen.sh
+REQUIRED_GNOME_DOC_UTILS_VERSION=0.10.0 
+REQUIRED_AUTOMAKE_VERSION=1.9 
+REQUIRED_GETTEXT_VERSION=0.12
+. gnome-autogen.sh
