@@ -120,11 +120,17 @@ class GtkNewGameDialog:
             
         # Create model for game time
         defaultTime = glchess.config.get('new_game_dialog/move_time')
+                  # Translators: Time Combo: There is no time limit
         times = [(_('Unlimited'),       0),
+                  # Translators: Time Combo: Game will last one minute
                  (_('One minute'),     60),
+                  # Translators: Time Combo: Game will last five minutes
                  (_('Five minutes'),  300),
+                  # Translators: Time Combo: Game will last 30 minutes
                  (_('30 minutes'),   1800),
+                  # Translators: Time Combo: Game will last one hour
                  (_('One hour'),     3600),
+                  # Translators: Time Combo: User will configure game duration
                  (_('Custom'),         -1)]
         timeModel = gtk.ListStore(str, int)
         activeIter = None
@@ -145,8 +151,11 @@ class GtkNewGameDialog:
         widget.add_attribute(cell, 'text', 0)
 
         model = gtk.ListStore(str, int)
+                  # Translators: Custom Time Combo: User specifying number of seconds for game duration
         units = [(_('seconds'),  1),
+                  # Translators: Custom Time Combo: User specifying number of minutes for game duration
                  (_('minutes'), 60),
+                  # Translators: Custom Time Combo: User specifying number of hours for game duration
                  (_('hours'), 3600)]
         for (name, multiplier) in units:
             iter = model.append()
@@ -164,8 +173,11 @@ class GtkNewGameDialog:
 
         # Create the model for difficulty options
         levelModel = gtk.ListStore(str, str, str)
+                  # Translators: AI Difficulty Combo: AI set to easy difficulty
         levels = [('easy',   _('Easy'),   'weather-few-clouds'),
+                  # Translators: AI Difficulty Combo: AI set to normal diffuculty
                   ('normal', _('Normal'), 'weather-overcast'),
+                  # Translators: AI Difficulty Combo: AI set to hard diffuculty
                   ('hard',   _('Hard'),   'weather-storm')]
         for (key, label, icon) in levels:
             iter = levelModel.append()
@@ -223,34 +235,40 @@ class GtkNewGameDialog:
             self.__setCombo('black_difficulty_combo', blackLevel)
 
         # Use supplied settings
-        errorText = ''
+        errors = []
         g = self.game
         if g is not None:
             self.__gui.get_widget('game_name_entry').set_text(g.name)
             self.__customName = True
+            # Translators: Error displayed when unable to load a game due to
+            # the require game engine not being available. %s is replaced with
+            # the name of the missing engine.
+            noEngineFormat = _('Unable to find %s engine')
             if not self.__setCombo('white_type_combo', g.white.type):
-                errorText += _('Unable to find %s engine\n') % repr(g.white.type)
+                errors.append(noEngineFormat % repr(g.white.type))
             self.__setCombo('white_difficulty_combo', g.white.level)
             if not self.__setCombo('black_type_combo', g.black.type):
-                errorText += _('Unable to find %s engine\n') % repr(g.black.type)
+                errors.append(noEngineFormat % repr(g.black.type))
             self.__setCombo('black_difficulty_combo', g.black.level)
             # TODO: Others
             
             # Change title for loaded games
             if g.path is not None:
+                # Translators: New Game Dialog: Title of the dialog when continuing a loaded game
                 self.window.set_title(_('Configure loaded game (%i moves)') % len(g.moves))
 
         # Display warning if missing the AIs
-        if len(errorText) > 0:
+        if len(errors) > 0:
+            # Translators: New Game Dialog: Title of error box when loaded game had AI engines missing
             self.__gui.get_widget('info_title_label').set_markup('<big><b>%s</b></big>' % _('Game settings changed'))
-            self.__gui.get_widget('info_description_label').set_markup('<i>%s</i>' % errorText[:-1])
+            self.__gui.get_widget('info_description_label').set_markup('<i>%s</i>' % '\n'.join(errors))
             self.__gui.get_widget('info_box').show()
 
         # Show the dialog
         self.window.present()
         self.__checking = False
         self.__testReady()
-        
+
     # Private methods
     
     def __setCombo(self, comboName, key):
@@ -296,7 +314,7 @@ class GtkNewGameDialog:
         if self.__customName:
             name = self.__gui.get_widget('game_name_entry').get_text()
             if len(name) == 0:
-                # Next time the something changes generate a name
+                # Next time something changes generate a name
                 self.__customName = False
                 ready = False
 
@@ -304,6 +322,7 @@ class GtkNewGameDialog:
         else:
             whiteName = self.__getComboData(self.__gui.get_widget('white_type_combo'), 2)
             blackName = self.__getComboData(self.__gui.get_widget('black_type_combo'), 2)
+            # Translators: Default name for a new game. %(white) and %(black) are substituted for the names of the white and black players.
             format = _('%(white)s versus %(black)s')
             self.__gui.get_widget('game_name_entry').set_text(format % {'white': whiteName, 'black': blackName})
 
@@ -327,12 +346,14 @@ class GtkNewGameDialog:
         # Get the players
         game.white.type  = self.__getComboData(self.__gui.get_widget('white_type_combo'), 0)
         if game.white.type == '':
+            # Translators: Default name for the white player
             game.white.name = _('White')
         else:
             game.white.name = self.__getComboData(self.__gui.get_widget('white_type_combo'), 2)
         game.white.level = self.__getComboData(self.__gui.get_widget('white_difficulty_combo'), 0)
         game.black.type  = self.__getComboData(self.__gui.get_widget('black_type_combo'), 0)
         if game.black.type == '':
+            # Translators: Default name for the black player
             game.black.name = _('Black')
         else:
             game.black.name = self.__getComboData(self.__gui.get_widget('black_type_combo'), 2)
@@ -384,6 +405,8 @@ class GtkNewGameDialog:
         if responseId == gtk.RESPONSE_OK:
             self.__startGame()
         dialog.destroy()
+        if self.__mainUI.newGameDialog is self:
+            self.__mainUI.newGameDialog = None
 
 class GtkLoadGameDialog:
     """
@@ -424,45 +447,38 @@ class GtkLoadGameDialog:
         fileChooser.add_filter(allFilter)
         
         self.window.present()
-        
-    def __getFilename(self):
-        """Get the currently selected filename.
-        
-        Returns the filename (string) or None if none selected.
-        """
-        return self.__gui.get_widget('filechooserwidget').get_filename()
-    
-    def _on_file_changed(self, widget):
-        """Gtk+ callback"""
-        name = self.__getFilename()
-        if name is None:
-            isFile = False
-        else:
-            isFile = os.path.isfile(name)
-        self.__gui.get_widget('properties_button').set_sensitive(isFile)
-        self.__gui.get_widget('open_button').set_sensitive(isFile)
-        
+            
     def _on_file_activated(self, widget):
         """Gtk+ callback"""
         self._on_response(self.window, gtk.RESPONSE_OK)
 
     def _on_response(self, dialog, responseId):
         """Gtk+ callback"""
-        chooser= self.__gui.get_widget('filechooserwidget')
+        chooser = self.__gui.get_widget('filechooserwidget')
 
         if responseId == gtk.RESPONSE_OK or responseId == gtk.RESPONSE_YES:
             folder = chooser.get_current_folder()
             if folder is not None:
                 glchess.config.set('load_directory', folder)
-            error = self.__mainUI.feedback.loadGame(self.__getFilename(), responseId == gtk.RESPONSE_YES)
+
+            fileName = self.__gui.get_widget('filechooserwidget').get_filename()
+            if fileName is None:
+                # Translators: Message displayed in load game dialog when no file is selected
+                error = _('Please select a file to load')
+            else:
+                error = self.__mainUI.feedback.loadGame(fileName, responseId == gtk.RESPONSE_YES)
+
             if error is not None:
                 self.firstExpose = True
                 self.__gui.get_widget('error_box').show()
+                # Translators: Title of error box when unable to load game
                 self.__gui.get_widget('error_title_label').set_markup('<big><b>%s</b></big>' % _('Unabled to load game'))
                 self.__gui.get_widget('error_description_label').set_markup('<i>%s</i>' % error)
                 return
 
         dialog.destroy()
+        if self.__mainUI.loadGameDialog is self:
+            self.__mainUI.loadGameDialog = None
         
 class GtkSaveGameDialog:
     """
@@ -525,6 +541,7 @@ class GtkSaveGameDialog:
             # Append .pgn to the end if not provided
             fname = chooser.get_filename()
             if fname is None:
+                # Translators: Save Game Dialog: Error displayed when no file name entered
                 self.__setError(_('Please enter a file name'), '')
                 return
             if fname[-4:].lower() != '.pgn':
@@ -537,6 +554,7 @@ class GtkSaveGameDialog:
 
             error = self.__mainUI._saveView(self.__view, fname)
             if error is not None:
+                # Translators: Save Game Dialog: Error title when unable to save game
                 self.__setError(_('Unabled to save game'), error)
                 return
         else:
@@ -558,70 +576,108 @@ class GtkPreferencesDialog:
         
         self.__gui.get_widget('preferences').set_transient_for(mainUI.mainWindow)
 
-        # Load preferences for move_format
-        moveFormat = glchess.config.get('move_format')
+        # Make model for move format
         moveModel = gtk.ListStore(str, str)
         widget = self.__gui.get_widget('move_format_combo')
         widget.set_model(moveModel)
+                        # Translators: Move Format Combo: Moves shown in human descriptive notation
         move_formats = [('human', _('Human')),
-                        ('lan', _('Long Algebraic')),
-                        ('san', _('Standard Algebraic'))]
+                        # Translators: Move Format Combo: Moves shown in standard algebraic notation (SAN)
+                        ('san', _('Standard Algebraic')),
+                        # Translators: Move Format Combo: Moves shown in standard figurine algebraic notation (FAN)
+                        ('fan', _('Figurine')),
+                        # Translators: Move Format Combo: Moves shown in long algebraic notation (LAN)
+                        ('lan', _('Long Algebraic'))]
         for (key, label) in move_formats:
             iter = moveModel.append()
-            if key == moveFormat:
-                widget.set_active_iter(iter)
             moveModel.set(iter, 0, label, 1, key)
 
-        # Load preferences for board orientation
-        boardView = glchess.config.get('board_view')
+        # Make model for board orientation
         boardModel = gtk.ListStore(str, str)
         widget = self.__gui.get_widget('board_combo')
         widget.set_model(boardModel)
+                     # Translators: Board Side Combo: Camera will face white player's side
         view_list = [('white', _('White Side')),
+                     # Translators: Board Side Combo: Camera will face black player's side
                      ('black', _('Black Side')),
+                     # Translators: Board Side Combo: Camera will face human player's side
                      ('human', _('Human Side')),
+                     # Translators: Board Side Combo: Camera will face current player's side
                      ('current', _('Current Player'))]
         for (key, label) in view_list:
             iter = boardModel.append()
-            if key == boardView:
-                widget.set_active_iter(iter)
             boardModel.set(iter, 0, label, 1, key)
 
-        # Load preferences for promotion type
-        promotionType = glchess.config.get('promotion_type')
+        # Make modelfor promotion type
         promotionModel = gtk.ListStore(str, str)
         widget = self.__gui.get_widget('promotion_type_combo')
         widget.set_model(promotionModel)
-        promotion_list = [('queen', _('Queen')),
-                          ('knight', _('Knight')),
-                          ('rook', _('Rook')),
-                          ('bishop', _('Bishop'))]
+                          # Translators: Promotion Combo: Promote to a queen. Do not translate the 'chess-piece|' text.
+        promotion_list = [('queen',  _('chess-piece|Queen')),
+                          # Translators: Promotion Combo: Promote to a knight. Do not translate the 'chess-piece|' text.
+                          ('knight', _('chess-piece|Knight')),
+                          # Translators: Promotion Combo: Promote to a rook. Do not translate the 'chess-piece|' text.
+                          ('rook',   _('chess-piece|Rook')),
+                          # Translators: Promotion Combo: Promote to a bishop. Do not translate the 'chess-piece|' text.
+                          ('bishop', _('chess-piece|Bishop'))]
         for (key, label) in promotion_list:
+            try:
+                label = label.split('|', 1)[1]
+            except IndexError:
+                pass
             iter = promotionModel.append()
-            if key == promotionType:
-                widget.set_active_iter(iter)
             promotionModel.set(iter, 0, label, 1, key)
+            
+        # Watch for config changes
+        for key in ['show_3d', 'show_toolbar', 'show_history', 
+                    'show_move_hints', 'show_numbering',
+                    'move_format', 'board_view', 'promotion_type']:
+            glchess.config.watch(key, self.__applyConfig)
+            try:
+                value = glchess.config.get(key)
+            except glchess.config.Error:
+                pass
+            else:
+                self.__applyConfig(key, value)
+        
+    def __applyConfig(self, name, value):
+        """
+        """        
+        if name == 'show_3d':
+            self.__gui.get_widget('show_3d').set_active(value)
 
-        # Load preferences for View settings.
-        pref = glchess.config.get('show_3d')
-        widget = self.__gui.get_widget('show_3d')
-        widget.set_active(pref)
+        elif name == 'show_toolbar':
+            self.__gui.get_widget('show_toolbar').set_active(value)
+                
+        elif name == 'show_history':
+            self.__gui.get_widget('show_history').set_active(value)
 
-        pref = glchess.config.get('show_toolbar')
-        widget = self.__gui.get_widget('show_toolbar')
-        widget.set_active(pref)
+        elif name == 'show_move_hints':
+            self.__gui.get_widget('show_move_hints').set_active(value)
 
-        pref = glchess.config.get('show_history')
-        widget = self.__gui.get_widget('show_history')
-        widget.set_active(pref)
+        elif name == 'show_numbering':
+            self.__gui.get_widget('show_numbering').set_active(value)
 
-        pref = glchess.config.get('show_move_hints')
-        widget = self.__gui.get_widget('show_move_hints')
-        widget.set_active(pref)
+        elif name == 'move_format':
+            widget = self.__gui.get_widget('move_format_combo')
+            for row in widget.get_model():
+                if row[1] == value:
+                    widget.set_active_iter(row.iter)
+                
+        elif name == 'promotion_type':
+            widget = self.__gui.get_widget('promotion_type_combo')
+            for row in widget.get_model():
+                if row[1] == value:
+                    widget.set_active_iter(row.iter)
+    
+        elif name == 'board_view':
+            widget = self.__gui.get_widget('board_combo')
+            for row in widget.get_model():
+                if row[1] == value:
+                    widget.set_active_iter(row.iter)
 
-        pref = glchess.config.get('show_numbering')
-        widget = self.__gui.get_widget('show_numbering')
-        widget.set_active(pref)
+        else:
+            assert(False), 'Unknown config item: %s' % name
 
     def setVisible(self, isVisible):
         window = self.__gui.get_widget('preferences')
@@ -643,6 +699,8 @@ class GtkPreferencesDialog:
         """Gtk+ callback"""
         model = widget.get_model()
         iter = widget.get_active_iter()
+        if iter is None:
+            return
         data = model.get(iter, 1)
         if data[0] is not None:
             glchess.config.set('move_format', data[0])
@@ -651,6 +709,8 @@ class GtkPreferencesDialog:
         """Gtk+ callback"""
         model = widget.get_model()
         iter = widget.get_active_iter()
+        if iter is None:
+            return
         data = model.get(iter, 1)
         if data[0] is not None:
             glchess.config.set('board_view', data[0])
@@ -659,6 +719,8 @@ class GtkPreferencesDialog:
         """Gtk+ callback"""
         model = widget.get_model()
         iter = widget.get_active_iter()
+        if iter is None:
+            return
         data = model.get(iter, 1)
         if data[0] is not None:
             glchess.config.set('promotion_type', data[0])
