@@ -20,12 +20,18 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
+#include <stdlib.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <games-scores-dialog.h>
-#include <games-scores.h>
-#include <games-sound.h>
+
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-sound.h>
 
 #include "main.h"
 #include "gnibbles.h"
@@ -73,7 +79,7 @@ gnibbles_error (GtkWidget * window, gchar * message)
   GtkWidget *w =
     gtk_message_dialog_new (GTK_WINDOW (window), GTK_DIALOG_MODAL,
 			    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-			    message);
+			    "%s", message);
   gtk_dialog_run (GTK_DIALOG (w));
   gtk_widget_destroy (GTK_WIDGET (w));
   exit (1);
@@ -85,15 +91,19 @@ gnibbles_load_pixmap_file (GtkWidget * window, const gchar * pixmap,
 {
   GdkPixbuf *image;
   gchar *filename;
+  const char *dirname;
 
-  filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					pixmap, TRUE, NULL);
+  dirname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  filename = g_build_filename (dirname, pixmap, NULL);
 
   if (!filename) {
     char *message =
       g_strdup_printf (_("Gnibbles couldn't find pixmap file:\n%s\n\n"
 			 "Please check your Gnibbles installation"), pixmap);
     gnibbles_error (window, message);
+    /* We should never get here since the app exits in gnibbles_error. But let's
+     * free it anyway in case someone comes along and changes gnibbles_error */
+    g_free(message);
   }
 
   image = gdk_pixbuf_new_from_file_at_size (filename, xsize, ysize, NULL);
@@ -168,7 +178,7 @@ gnibbles_load_logo (GtkWidget * window)
   if (logo_pixmap)
     g_object_unref (logo_pixmap);
   logo_pixmap =
-    gnibbles_load_pixmap_file (window, "pixmaps/gnibbles/gnibbles-logo.svg",
+    gnibbles_load_pixmap_file (window, "gnibbles-logo.svg",
 			       width, height);
 }
 
@@ -176,36 +186,36 @@ void
 gnibbles_load_pixmap (GtkWidget * window)
 {
   gchar *bonus_files[] = {
-    "pixmaps/gnibbles/blank.svg",
-    "pixmaps/gnibbles/diamond.svg",
-    "pixmaps/gnibbles/bonus1.svg",
-    "pixmaps/gnibbles/bonus2.svg",
-    "pixmaps/gnibbles/life.svg",
-    "pixmaps/gnibbles/bonus3.svg",
-    "pixmaps/gnibbles/bonus4.svg",
-    "pixmaps/gnibbles/bonus5.svg",
-    "pixmaps/gnibbles/questionmark.svg"
+    "blank.svg",
+    "diamond.svg",
+    "bonus1.svg",
+    "bonus2.svg",
+    "life.svg",
+    "bonus3.svg",
+    "bonus4.svg",
+    "bonus5.svg",
+    "questionmark.svg"
   };
   gchar *small_files[] = {
-    "pixmaps/gnibbles/wall-empty.svg",
-    "pixmaps/gnibbles/wall-straight-up.svg",
-    "pixmaps/gnibbles/wall-straight-side.svg",
-    "pixmaps/gnibbles/wall-corner-bottom-left.svg",
-    "pixmaps/gnibbles/wall-corner-bottom-right.svg",
-    "pixmaps/gnibbles/wall-corner-top-left.svg",
-    "pixmaps/gnibbles/wall-corner-top-right.svg",
-    "pixmaps/gnibbles/wall-tee-up.svg",
-    "pixmaps/gnibbles/wall-tee-right.svg",
-    "pixmaps/gnibbles/wall-tee-left.svg",
-    "pixmaps/gnibbles/wall-tee-down.svg",
-    "pixmaps/gnibbles/wall-cross.svg",
-    "pixmaps/gnibbles/snake-red.svg",
-    "pixmaps/gnibbles/snake-green.svg",
-    "pixmaps/gnibbles/snake-blue.svg",
-    "pixmaps/gnibbles/snake-yellow.svg",
-    "pixmaps/gnibbles/snake-cyan.svg",
-    "pixmaps/gnibbles/snake-magenta.svg",
-    "pixmaps/gnibbles/snake-grey.svg"
+    "wall-empty.svg",
+    "wall-straight-up.svg",
+    "wall-straight-side.svg",
+    "wall-corner-bottom-left.svg",
+    "wall-corner-bottom-right.svg",
+    "wall-corner-top-left.svg",
+    "wall-corner-top-right.svg",
+    "wall-tee-up.svg",
+    "wall-tee-right.svg",
+    "wall-tee-left.svg",
+    "wall-tee-down.svg",
+    "wall-cross.svg",
+    "snake-red.svg",
+    "snake-green.svg",
+    "snake-blue.svg",
+    "snake-yellow.svg",
+    "snake-cyan.svg",
+    "snake-magenta.svg",
+    "snake-grey.svg"
   };
   int i;
 
@@ -230,22 +240,26 @@ void
 gnibbles_load_level (GtkWidget * window, gint level)
 {
   gchar *tmp = NULL;
+  const char *dirname;
   gchar *filename;
   FILE *in;
   gchar tmpboard[BOARDWIDTH + 2];
   gint i, j;
   gint count = 0;
 
-  tmp = g_strdup_printf ("gnibbles/level%03d.gnl", level);
-  filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					tmp, TRUE, NULL);
+  tmp = g_strdup_printf ("level%03d.gnl", level);
+
+  dirname = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
+  filename = g_build_filename (dirname, tmp, NULL);
+
   g_free (tmp);
   if ((in = fopen (filename, "r")) == NULL) {
     char *message =
       g_strdup_printf (_
-		       ("Gnibbles couldn't load level file:\n%s\n\n"
-			"Please check your Gnibbles installation"), filename);
+                       ("Gnibbles couldn't load level file:\n%s\n\n"
+                        "Please check your Gnibbles installation"), filename);
     gnibbles_error (window, message);
+    g_free (message);
   }
 
   g_free (filename);
@@ -261,33 +275,41 @@ gnibbles_load_level (GtkWidget * window, gint level)
   boni = gnibbles_boni_new ();
 
   for (i = 0; i < BOARDHEIGHT; i++) {
-    fgets (tmpboard, sizeof (tmpboard), in);
+    if (!fgets (tmpboard, sizeof (tmpboard), in)) {
+      char *message =
+        g_strdup_printf (_
+                         ("Level file appears to be damaged:\n%s\n\n"
+                         "Please check your Gnibbles installation"), filename);
+      gnibbles_error (window, message);
+      g_free (message);
+      break;
+    }
     for (j = 0; j < BOARDWIDTH; j++) {
       board[j][i] = tmpboard[j];
       switch (board[j][i]) {
       case 'm':
-	board[j][i] = 'a';
-	if (count < properties->numworms)
-	  gnibbles_worm_set_start (worms[count++], j, i, WORMUP);
-	break;
+        board[j][i] = 'a';
+        if (count < properties->numworms)
+          gnibbles_worm_set_start (worms[count++], j, i, WORMUP);
+        break;
       case 'n':
-	board[j][i] = 'a';
-	if (count < properties->numworms)
-	  gnibbles_worm_set_start (worms[count++], j, i, WORMLEFT);
-	break;
+        board[j][i] = 'a';
+        if (count < properties->numworms)
+          gnibbles_worm_set_start (worms[count++], j, i, WORMLEFT);
+        break;
       case 'o':
-	board[j][i] = 'a';
-	if (count < properties->numworms)
-	  gnibbles_worm_set_start (worms[count++], j, i, WORMDOWN);
-	break;
+        board[j][i] = 'a';
+        if (count < properties->numworms)
+          gnibbles_worm_set_start (worms[count++], j, i, WORMDOWN);
+        break;
       case 'p':
-	board[j][i] = 'a';
-	if (count < properties->numworms)
-	  gnibbles_worm_set_start (worms[count++], j, i, WORMRIGHT);
-	break;
+        board[j][i] = 'a';
+        if (count < properties->numworms)
+          gnibbles_worm_set_start (worms[count++], j, i, WORMRIGHT);
+        break;
       case 'Q':
-	gnibbles_warpmanager_add_warp (warpmanager, j - 1, i - 1, -1, -1);
-	break;
+        gnibbles_warpmanager_add_warp (warpmanager, j - 1, i - 1, -1, -1);
+        break;
       case 'R':
       case 'S':
       case 'T':
@@ -297,9 +319,9 @@ gnibbles_load_level (GtkWidget * window, gint level)
       case 'X':
       case 'Y':
       case 'Z':
-	gnibbles_warpmanager_add_warp
-	  (warpmanager, j - 1, i - 1, -board[j][i], 0);
-	break;
+        gnibbles_warpmanager_add_warp
+          (warpmanager, j - 1, i - 1, -board[j][i], 0);
+        break;
       case 'r':
       case 's':
       case 't':
@@ -309,22 +331,22 @@ gnibbles_load_level (GtkWidget * window, gint level)
       case 'x':
       case 'y':
       case 'z':
-	gnibbles_warpmanager_add_warp
-	  (warpmanager, -(board[j][i] - 'a' + 'A'), 0, j, i);
-	board[j][i] = EMPTYCHAR;
-	break;
+        gnibbles_warpmanager_add_warp
+          (warpmanager, -(board[j][i] - 'a' + 'A'), 0, j, i);
+        board[j][i] = EMPTYCHAR;
+        break;
       }
       /* Warpmanager draws the warp points. Everything else gets drawn here. */
       if (board[j][i] >= 'a')
-	gnibbles_draw_pixmap_buffer (board[j][i] - 'a', j, i);
+        gnibbles_draw_pixmap_buffer (board[j][i] - 'a', j, i);
     }
   }
 
   gdk_draw_drawable (GDK_DRAWABLE (drawing_area->window),
-		     drawing_area->style->
-		     fg_gc[GTK_WIDGET_STATE (drawing_area)], buffer_pixmap, 0,
-		     0, 0, 0, BOARDWIDTH * properties->tilesize,
-		     BOARDHEIGHT * properties->tilesize);
+                     drawing_area->style->
+                     fg_gc[GTK_WIDGET_STATE (drawing_area)], buffer_pixmap, 0,
+                     0, 0, 0, BOARDWIDTH * properties->tilesize,
+                     BOARDHEIGHT * properties->tilesize);
 
   fclose (in);
 }
