@@ -20,11 +20,15 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
 #include <stdlib.h>
 #include <math.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
 
 #include "gbdefs.h"
 #include "gameconfig.h"
@@ -113,7 +117,7 @@ message_box (gchar * msg)
   GtkWidget *box;
 
   box = gtk_message_dialog_new (GTK_WINDOW (app), GTK_DIALOG_MODAL,
-				GTK_MESSAGE_INFO, GTK_BUTTONS_OK, msg);
+				GTK_MESSAGE_INFO, GTK_BUTTONS_OK, "%s", msg);
   gtk_dialog_run (GTK_DIALOG (box));
   gtk_widget_destroy (box);
 }
@@ -670,7 +674,7 @@ init_game (void)
   create_game_timer ();
 
   g_signal_connect (GTK_OBJECT (app), "key_press_event",
-		    GTK_SIGNAL_FUNC (keyboard_cb), 0);
+		    G_CALLBACK (keyboard_cb), 0);
 
   start_new_game ();
 }
