@@ -40,13 +40,11 @@ def inactivate_new_game_etc (fun):
     def _ (ui, *args, **kwargs):
         paths = [
             '/MenuBar/Game/New',
-            #'/MenuBar/Game/Open',
-            #'/MenuBar/Game/ByHand',
             '/MenuBar/Game/Print',
-            '/MenuBar/Edit/Undo',
-            '/MenuBar/Edit/Redo',
+            # undo/redo is handled elsewhere as it can't simply be turned on/off.
             '/MenuBar/Edit/Clear',
             '/MenuBar/Edit/ClearNotes',
+            '/MenuBar/View/ToggleToolbar',
             '/MenuBar/Tools/ShowPossible',
             '/MenuBar/Tools/AutofillCurrentSquare',
             '/MenuBar/Tools/Autofill',
@@ -54,7 +52,6 @@ def inactivate_new_game_etc (fun):
             '/MenuBar/Tools/ShowImpossibleImplications',
             '/MenuBar/Tools/Tracker',
             '/MenuBar/Game/PuzzleInfo',
-            #'/MenuBar/Game/HighScores',
             ]
         for p in paths:
             action = ui.uimanager.get_action(p)
@@ -178,7 +175,6 @@ class UI (gconf_wrapper.GConfWrapper):
         self.won = False
         # add the accelerator group to our toplevel window
         self.worker_connections=[]
-        self.timer.start_timing()
         # setup sudoku maker...
         self.sudoku_maker = sudoku_maker.SudokuMaker()
         self.sudoku_tracker = saver.SudokuTracker()
@@ -216,11 +212,16 @@ class UI (gconf_wrapper.GConfWrapper):
         if not choice:
             return True
         #print 'choice is ',choice
+        self.timer.start_timing()
         if choice[0] == game_selector.NewOrSavedGameSelector.NEW_GAME:
             self.gsd.change_grid(choice[1],9)
         if choice[0] == game_selector.NewOrSavedGameSelector.SAVED_GAME:
             saver.open_game(self,choice[1])
-        if self.gconf['show_toolbar']: self.tb.show()
+        if self.gconf['show_toolbar']: 
+            self.tb.show()
+        if self.gconf['always_show_hints']:
+            self.gsd.update_all_hints()
+
 
     def show (self):
         self.gsd.show()
@@ -329,7 +330,7 @@ class UI (gconf_wrapper.GConfWrapper):
         self.edit_actions = gtk.ActionGroup('EditActions')
         self.edit_actions.add_actions(
             [('Edit',None,_('_Edit')),
-             ('Undo',gtk.STOCK_UNDO,_('_Undo'),'<Control>z',_('Undo last action')),
+             ('Undo',gtk.STOCK_UNDO,_('_Undo'),'<Control>z',_('Undo last action'), self.stop_dancer),
              ('Redo',gtk.STOCK_REDO,_('_Redo'),'<Shift><Control>z',_('Redo last action')),
              ('Clear',gtk.STOCK_CLEAR,_('_Clear'),'<Control>b',_("Clear entries you've filled in"),self.clear_cb),
              ('ClearNotes',None,_('Clear _Notes'),None,_("Clear notes and hints"),self.clear_notes_cb),             
@@ -456,8 +457,15 @@ class UI (gconf_wrapper.GConfWrapper):
             for c in self.worker_connections:
                 self.timer.disconnect(c)
 
+    def stop_dancer (self, *args):
+        if hasattr(self, 'dancer'):
+             self.dancer.stop_dancing()
+             delattr(self, 'dancer')
+
     @simple_debug
     def you_win_callback (self,grid):
+        if hasattr(self, 'dancer'):
+            return
         self.won = True
         # increase difficulty for next time.
         self.gconf['difficulty']=self.gconf['difficulty']+0.1
@@ -538,13 +546,9 @@ class UI (gconf_wrapper.GConfWrapper):
             self.do_stop()
             
     def do_stop (self):
-        if hasattr(self,'dancer'):
-            self.dancer.stop_dancing()
-            delattr(self,'dancer')
+        self.stop_dancer()
         self.gsd.grid = None
         self.tracker_ui.reset()
-        self.timer.reset_timer()
-        self.timer.start_timing()
         self.history.clear()        
         self.won = False
         
@@ -655,12 +659,24 @@ class UI (gconf_wrapper.GConfWrapper):
     @simple_debug
     def clear_cb (self,*args):        
         clearer=Undo.UndoableObject(
-            lambda *args: self.cleared.append(self.gsd.reset_grid()), #action
-            lambda *args: [self.gsd.add_value_to_ui(*entry) for entry in self.cleared.pop()], #inverse
+            self.do_clear, #action
+            self.undo_clear, #inverse
             self.history #history
             )
         clearer.perform()
 
+    # add a check to stop the dancer if she is dancing
+    def do_clear (self, *args):
+        self.cleared.append(self.gsd.reset_grid())
+        self.stop_dancer()
+
+    # add a check for finish in the undo to clear
+    def undo_clear (self, *args):
+        for entry in self.cleared.pop():
+            self.gsd.add_value_to_ui(*entry) 
+        if self.gsd.grid.check_for_completeness():
+            self.gsd.emit('puzzle-finished')
+
     def clear_notes_cb (self, *args):
         clearer = Undo.UndoableObject(
             lambda *args: self.cleared_notes.append(self.gsd.clear_notes()), #action
@@ -696,12 +712,23 @@ class UI (gconf_wrapper.GConfWrapper):
         if not hasattr(self,'autofilled'): self.autofilled=[]
         if not hasattr(self,'autofiller'):
             self.autofiller = Undo.UndoableObject(
-                lambda *args: self.autofilled.append(self.gsd.auto_fill()),
-                lambda *args: [self.gsd.remove(entry[0],entry[1],do_removal=True) for entry in self.autofilled.pop()],
+                self.do_auto_fill,
+                self.undo_auto_fill,
                 self.history
                 )
         self.autofiller.perform()
 
+    def do_auto_fill (self, *args):
+        self.autofilled.append(self.gsd.auto_fill())
+        if self.gconf['always_show_hints']:
+            self.gsd.update_all_hints()
+
+    def undo_auto_fill (self, *args):
+        for entry in self.autofilled.pop():
+            self.gsd.remove(entry[0],entry[1],do_removal=True)
+        if self.gconf['always_show_hints']:
+            self.gsd.update_all_hints()
+
     @simple_debug
     def auto_fill_current_square_cb (self, *args):
         self.gsd.auto_fill_current_entry()
@@ -770,20 +797,6 @@ class UI (gconf_wrapper.GConfWrapper):
         self.current_puzzle_string = puzz
 	tot_string = _("Playing %(difficulty)s puzzle.")%{'difficulty':self.current_puzzle_diff.value_string()}
         tot_string += " " + "(%1.2f)"%self.current_puzzle_diff.value
-        #if self.timer.tot_time or self.timer.tot_time_complete:
-        #    time_string = _("%s (%s active)")%(
-        #        self.timer.total_time_string(),
-        #        self.timer.active_time_string()
-        #        )
-        #    if not self.timer.__timing__:
-        #        time_string += " %s"%_('paused')
-        #    tot_string += " - " + time_string
-        #if self.gsd.hints and not self.gconf['always_show_hints']:
-        #    tot_string += " -  " +ngettext("%(n)s hint","%(n)s hints",
-        #                           self.gsd.hints)%{'n':self.gsd.hints}
-        #if self.gsd.auto_fills:
-        #    tot_string += "  " +ngettext("%(n)s auto-fill","%(n)s auto-fills",
-        #                            self.gsd.auto_fills)%{'n':self.gsd.auto_fills}
         self.set_statusbar_value(tot_string)
         return True
 
