@@ -20,6 +20,25 @@
  * For more details see the file COPYING.
  */
 
+#include <config.h>
+
+#include <dirent.h>
+#include <string.h>
+#include <math.h>
+#include <ctype.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
+#include <gio/gio.h>
+
+#include <libgames-support/games-controls.h>
+#include <libgames-support/games-frame.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-sound.h>
+#include <libgames-support/games-stock.h>
+
 #include "tetris.h"
 #include "field.h"
 #include "blockops.h"
@@ -29,20 +48,6 @@
 #include "highscores.h"
 #include "renderer.h"
 
-#include <games-frame.h>
-#include <games-controls.h>
-#include <games-stock.h>
-#include <games-sound.h>
-
-#include <libgnomevfs/gnome-vfs.h>
-
-#include <gdk/gdkkeysyms.h>
-#include <config.h>
-#include <dirent.h>
-#include <string.h>
-#include <math.h>
-#include <ctype.h>
-
 int LINES = 20;
 int COLUMNS = 14;
 
@@ -94,6 +99,8 @@ Tetris::Tetris(int cmdlLevel):
 	GtkWidget *menubar;
 
 	gchar *outdir;
+	const char *dname;
+
 	const GtkTargetEntry targets[] = {{(gchar*) "text/uri-list", 0, URI_LIST}, 
 					  {(gchar*) "property/bgimage", 0, URI_LIST},
 					  {(gchar*) "text/plain", 0, TEXT_PLAIN},
@@ -141,8 +148,8 @@ Tetris::Tetris(int cmdlLevel):
 	
 
 	/* Locate our background image. */
-	outdir = g_build_filename (gnome_user_dir_get (), "gnometris.d", 
-				   NULL);
+
+	outdir = g_build_filename (g_get_user_data_dir (), "gnometris", NULL);
 	if (!g_file_test (outdir, G_FILE_TEST_EXISTS))
 	    mkdir (outdir, 0700);
 	bgPixmap = g_build_filename (outdir, "background.bin", NULL);
@@ -150,13 +157,14 @@ Tetris::Tetris(int cmdlLevel):
 
 	/*  Use default background image, if none found in user's home dir.*/
 	if (!g_file_test (bgPixmap, G_FILE_TEST_EXISTS)) {
-          defaultPixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					        "pixmaps/gnometris/gnometris.svg",
-						 TRUE, NULL);
+          dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+          defaultPixmap = g_build_filename (dname, "gnometris.svg", NULL);
 	  default_bgimage = true;
 	}
 	
-	w = gnome_app_new("gnometris", _("Gnometris"));
+	w = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (w), _("Gnometris"));
+
 	g_signal_connect (w, "delete_event", G_CALLBACK (gameQuit), this);
 	gtk_drag_dest_set (w, GTK_DEST_DEFAULT_ALL, targets, 
 			   G_N_ELEMENTS(targets), 
@@ -203,7 +211,7 @@ Tetris::Tetris(int cmdlLevel):
 	GtkWidget * hb = gtk_hbox_new(FALSE, 0);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	gnome_app_set_contents (GNOME_APP (w), vbox);
+	gtk_container_add (GTK_CONTAINER (w), vbox);
 	gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hb, TRUE, TRUE, 0);
 
@@ -216,8 +224,8 @@ Tetris::Tetris(int cmdlLevel):
 
 	GtkWidget *vb1 = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vb1), 10);
-	gtk_box_pack_start_defaults(GTK_BOX(vb1), aspect_frame);
-	gtk_box_pack_start_defaults(GTK_BOX(hb), vb1);
+	gtk_box_pack_start(GTK_BOX(vb1), aspect_frame, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(hb), vb1, TRUE, TRUE, 0);
 
 	setupPixmap();
 
@@ -240,6 +248,7 @@ Tetris::Tetris(int cmdlLevel):
 
 	themeList = NULL;
 	
+	gtk_widget_show(vbox);
 	gtk_widget_show(hb);
 	gtk_widget_show(vb1);
 	gtk_widget_show(vb2);
@@ -570,65 +579,6 @@ Tetris::startingLevelChanged (GtkWidget *spin, gpointer data)
         games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_STARTING_LEVEL, value);
 }
 
-void
-Tetris::fillMenu(GtkWidget *menu, char *pixname, char *dirname, 
-		 GList ** listp, bool addnone /*= false*/)
-{
-	struct dirent *e;
-	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, dirname, FALSE, NULL);
-	DIR *dir;
-	int itemno = 0;
-	GList * list;
-
-	list = *listp;
-
-	if (list) {
-		g_list_foreach (list, (GFunc) g_free, NULL);
-		g_list_free (list);
-		*listp = NULL;
-	}
-	
-	dir = opendir (dname);
-
-	if (!dir)
-		return;
-	
-	char *s;
-	
-	while ((e = readdir (dir)) != 0)
-	{
-		s = g_strdup(e->d_name);
-
-		if (!(strstr (e->d_name, ".png") || 
-		      strstr (e->d_name, ".jpg") ||
-		      strstr (e->d_name, ".svg"))) 
-		{
-			free(s);
-			continue;
-		}
-
-		gtk_combo_box_append_text (GTK_COMBO_BOX (menu), s);
-		*listp = g_list_append (*listp, s);
-			  
-		if (!strcmp(pixname, s))
-		{
-		  gtk_combo_box_set_active(GTK_COMBO_BOX (menu), itemno);
-		}
-		itemno++;
-	}
-	
-	if (addnone)
-	{
-        /* Translators: This is the placeholder item in the theme combo box
-           (preferences dialog) when no themes are available */
-		s = g_strdup(_("<none>"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _("<none>"));
-		*listp = g_list_append (*listp, s);
-	}
-	
-	closedir(dir);
-}
-
 int 
 Tetris::gameProperties(GtkAction *action, void *d)
 {
@@ -725,7 +675,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 			  (GtkAttachOptions) 0,
 			  0, 0);
 
-	adj = gtk_adjustment_new (t->startingLevel, 1, 20, 1, 5, 20);
+	adj = gtk_adjustment_new (t->startingLevel, 1, 20, 1, 5, 0);
 	t->sentry = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 10.0, 0);
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (t->sentry),
 					   GTK_UPDATE_ALWAYS);
@@ -1087,7 +1037,7 @@ Tetris::resetColour (Tetris *t)
 	t->saveBgOptions ();
 }
 
-gchar * 
+char * 
 Tetris::decodeDropData(gchar * data, gint type)
 {
 	gchar *start, *end;
@@ -1129,16 +1079,20 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 		 gint x, gint y, GtkSelectionData *data, guint info, 
 		 guint time, Tetris * t)
 {
-	gchar * fileuri;
-	GnomeVFSHandle *inhandle;
-	GnomeVFSHandle *outhandle;
-	GnomeVFSResult result;
-	GnomeVFSFileInfo fileinfo;
-	GnomeVFSFileSize bytesread;
-	GnomeVFSFileSize filesize;
-	GdkPixbufLoader * loader;
-	GdkPixbuf * pixbuf;
-	guchar * buffer;
+	const char *fileuri;
+
+	GError *error;
+	GFile *file;
+	GFile *outfile;
+	GFileInfo *fileinfo;
+	GFileInputStream *istream;
+	GFileOutputStream *outstream;
+	goffset filesize;
+	gssize bytesread, byteswrote;
+
+	GdkPixbufLoader *loader;
+	GdkPixbuf *pixbuf;
+	guchar *buffer;
 
 
 	/* Accept a dropped filename and try and load it as the
@@ -1167,40 +1121,35 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 		return;
 	}
 
-	fileuri = decodeDropData ((gchar *)data->data, info);
+	fileuri = decodeDropData ((char *)data->data, info);
 	/* Silently ignore bad data. */
 	if (fileuri == NULL)
 		goto error_exit;
 
 	/* Now that we have a URI we load it and test it to see if it is 
 	 * an image file. */
-
-	/* FIXME: All this is slow and synchronous. It also
-	 * doesn't give any feedback about errors. */
 	
-	result = gnome_vfs_open (&inhandle, fileuri, GNOME_VFS_OPEN_READ);
-	if (result != GNOME_VFS_OK)
+	file = g_file_new_for_uri (fileuri);
+	istream = g_file_read (file, NULL, &error);
+
+	if (error)
 		goto error_exit;
 
-	result = gnome_vfs_get_file_info_from_handle (inhandle, &fileinfo,
-						      GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
-	if (result != GNOME_VFS_OK)
+	fileinfo =  g_file_input_stream_query_info (istream, (char *)G_FILE_ATTRIBUTE_STANDARD_SIZE, NULL, &error);
+
+	if (error)
 		goto error_exit_handle;
 
-	/* This is where Drag and Drop of URLs from mozilla fails. */
-
-	if (!(fileinfo.valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE))
-		goto error_exit_handle;
-
-	filesize = fileinfo.size;
+	filesize = g_file_info_get_size (fileinfo);
 
 	buffer = (guchar *)g_malloc (filesize);
 	if (buffer == NULL)
 		goto error_exit_handle;
 	
-	result = gnome_vfs_read (inhandle, buffer, filesize, &bytesread);
+	bytesread = g_input_stream_read (G_INPUT_STREAM (istream), buffer, filesize, NULL, &error);
+
 	/* FIXME: We should reread if not enough was read. */
-	if ((result != GNOME_VFS_OK) || (bytesread != filesize))
+	if (error || (bytesread != filesize))
 		goto error_exit_buffer;
 
 	loader = gdk_pixbuf_loader_new ();
@@ -1220,27 +1169,33 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 	 * can handle. Now we save it to disk. This is necessary so that
 	 * "slow" URIs (e.g. http) behave well in the long run. */
 
-	result = gnome_vfs_create (&outhandle, t->bgPixmap, GNOME_VFS_OPEN_WRITE,
-				   FALSE, 0600);
-	if (result != GNOME_VFS_OK)
+	outfile = g_file_new_for_path (t->bgPixmap);
+	outstream = g_file_replace (outfile, NULL, FALSE, G_FILE_CREATE_PRIVATE,
+					NULL, &error);
+
+	if (error)
 		goto error_exit_loader;
 
-	result = gnome_vfs_write (outhandle, buffer, filesize, &bytesread);
-	if ((result != GNOME_VFS_OK) || (bytesread != filesize))
+	byteswrote = g_output_stream_write (G_OUTPUT_STREAM (outstream), buffer,
+						bytesread, NULL, &error);
+
+	if (byteswrote != filesize)
 	    goto error_exit_saver;
 
 	t->usebg = TRUE;
 	t->saveBgOptions ();
 
  error_exit_saver:
-	gnome_vfs_close (outhandle);
+	g_object_unref(outstream);
  error_exit_loader:
 	g_object_unref (loader);
  error_exit_buffer:
 	g_free (buffer);
  error_exit_handle:
-	gnome_vfs_close (inhandle);
+	g_object_unref(istream);
  error_exit:
+	if(error)
+		g_error_free(error);
 	return;
 }
 
@@ -1360,10 +1315,10 @@ Tetris::gameNew(GtkAction *action, void *d)
 }
 
 int
-Tetris::gameHelp(GtkAction *action, void *d)
+Tetris::gameHelp(GtkAction *action, void *data)
 {
-	gnome_help_display ("gnometris.xml", NULL, NULL);
-
+	Tetris *t = (Tetris*) data;
+	games_help_display(t->getWidget(), "gnometris", NULL);
 	return TRUE;
 }
 
