@@ -22,9 +22,12 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <games-conf.h>
+
+#include <libgames-support/games-conf.h>
 
 #define KEY_OPTIONS_GROUP             "options"
 #define KEY_BG_COLOUR                 "bgcolor"
@@ -162,9 +165,6 @@ private:
 
   GdkColor bgcolour;
 
-  void fillMenu (GtkWidget * menu, char *pixname, char *dirname,
-		 GList ** list, bool addnone = false);
-
   GtkWidget *setupdialog;
   GtkWidget *sentry;
   int startingLevel;
