@@ -24,18 +24,27 @@
  */
 
 #include <config.h>
-#include <gnome.h>
-#include <glib/gi18n.h>
+#include <stdlib.h>
+
 #include <string.h>
-/*#include <gst/gst.h>*/
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include <libgames-support/games-clock.h>
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-frame.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-scores.c>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-stock.h>
+
+#ifdef WITH_SMCLIENT
+#include <libgames-support/eggsmclient.h>
+#endif /* WITH_SMCLIENT */
 
 #include "minefield.h"
-#include <games-clock.h>
-#include <games-frame.h>
-#include <games-scores.c>
-#include <games-scores-dialog.h>
-#include <games-stock.h>
-#include <games-conf.h>
 
 #define APP_NAME "gnomine"
 #define APP_NAME_LONG N_("Mines")
@@ -121,11 +130,12 @@ image_widget_setup (char *name)
 {
   GtkWidget *image = NULL;
   char *filename = NULL;
+  const char *dname;
 
   image = gtk_image_new ();
-  filename = gnome_program_locate_file (NULL,
-					GNOME_FILE_DOMAIN_APP_PIXMAP, name,
-					TRUE, NULL);
+  dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  filename = g_build_filename (dname, name, NULL);
+
   if (filename != NULL)
     gtk_image_set_from_file (GTK_IMAGE (image), filename);
 
@@ -282,6 +292,8 @@ new_game (void)
 
   set_flabel (GTK_MINEFIELD (mfield));
 
+  gtk_action_set_visible (pause_action, TRUE);
+  gtk_action_set_visible (resume_action, FALSE);
   gtk_widget_hide (resume_container);
   gtk_widget_show (mfield_container);
 }
@@ -655,7 +667,7 @@ create_preferences (void)
   if (fsize == 0)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
   g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
+		    G_CALLBACK (size_radio_callback),
 		    GINT_TO_POINTER (0));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
@@ -665,7 +677,7 @@ create_preferences (void)
   if (fsize == 1)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
   g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
+		    G_CALLBACK (size_radio_callback),
 		    GINT_TO_POINTER (1));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
@@ -674,7 +686,7 @@ create_preferences (void)
   if (fsize == 2)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
   g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
+		    G_CALLBACK (size_radio_callback),
 		    GINT_TO_POINTER (2));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
@@ -683,7 +695,7 @@ create_preferences (void)
   if (fsize == 3)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
   g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
+		    G_CALLBACK (size_radio_callback),
 		    GINT_TO_POINTER (3));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
@@ -705,7 +717,7 @@ create_preferences (void)
 
   mentry = gtk_spin_button_new_with_range (1, XSIZE_MAX * YSIZE_MAX, 1);
   g_signal_connect (GTK_OBJECT (mentry), "value-changed",
-		    GTK_SIGNAL_FUNC (nmines_spin_cb), NULL);
+		    G_CALLBACK (nmines_spin_cb), NULL);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (mentry), nmines);
   gtk_table_attach (GTK_TABLE (table2), mentry, 1, 2, 2, 3, 0, 0, 0, 0);
   fix_nmines (xsize, ysize);
@@ -718,7 +730,7 @@ create_preferences (void)
 
   xentry = gtk_spin_button_new_with_range (XSIZE_MIN, XSIZE_MAX, 1);
   g_signal_connect (GTK_OBJECT (xentry), "value-changed",
-		    GTK_SIGNAL_FUNC (xsize_spin_cb), NULL);
+		    G_CALLBACK (xsize_spin_cb), NULL);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (xentry), xsize);
   gtk_table_attach (GTK_TABLE (table2), xentry, 1, 2, 0, 1, 0, 0, 0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), xentry);
@@ -730,7 +742,7 @@ create_preferences (void)
 
   yentry = gtk_spin_button_new_with_range (YSIZE_MIN, YSIZE_MAX, 1);
   g_signal_connect (GTK_OBJECT (yentry), "value-changed",
-		    GTK_SIGNAL_FUNC (ysize_spin_cb), NULL);
+		    G_CALLBACK (ysize_spin_cb), NULL);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (yentry), ysize);
   gtk_table_attach (GTK_TABLE (table2), yentry, 1, 2, 1, 2, 0, 0, 0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), yentry);
@@ -743,7 +755,7 @@ create_preferences (void)
   question_toggle =
     gtk_check_button_new_with_mnemonic (_("_Use \"I'm not sure\" flags"));
   g_signal_connect (GTK_OBJECT (question_toggle), "toggled",
-		    GTK_SIGNAL_FUNC (use_question_toggle_cb), NULL);
+		    G_CALLBACK (use_question_toggle_cb), NULL);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (question_toggle),
 				use_question_marks);
   gtk_widget_show (question_toggle);
@@ -754,7 +766,7 @@ create_preferences (void)
   overmine_toggle =
     gtk_check_button_new_with_mnemonic (_("_Use \"Too many flags\" warning"));
   g_signal_connect (GTK_OBJECT (overmine_toggle), "toggled",
-		    GTK_SIGNAL_FUNC (use_overmine_toggle_cb), NULL);
+		    G_CALLBACK (use_overmine_toggle_cb), NULL);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (overmine_toggle),
 				use_overmine_warning);
   gtk_widget_show (overmine_toggle);
@@ -795,7 +807,7 @@ preferences_callback (void)
 static void
 help_callback (void)
 {
-  gnome_help_display ("gnomine.xml", NULL, NULL);
+  games_help_display (window, "gnomine", NULL);
 }
 
 const GtkActionEntry actions[] = {
@@ -873,45 +885,50 @@ create_ui_manager (const gchar * group)
   return ui_manager;
 }
 
+#ifdef WITH_SMCLIENT
 static int
-save_state (GnomeClient * client,
-	    gint phase,
-	    GnomeRestartStyle save_style,
-	    gint shutdown,
-	    GnomeInteractStyle interact_style,
-	    gint fast, gpointer client_data)
+save_state_cb (EggSMClient *client,
+	    GKeyFile* keyfile,
+	    gpointer client_data)
 {
   char *argv[20];
-  int i = 0, j;
+  int argc = 0, j;
   gint xpos, ypos;
 
   gdk_window_get_origin (window->window, &xpos, &ypos);
 
-  argv[i++] = (char *) client_data;
-  argv[i++] = "-x";
-  argv[i++] = g_strdup_printf ("%d", xsize);
-  argv[i++] = "-y";
-  argv[i++] = g_strdup_printf ("%d", ysize);
-  argv[i++] = "-n";
-  argv[i++] = g_strdup_printf ("%d", nmines);
-  argv[i++] = "-f";
-  argv[i++] = g_strdup_printf ("%d", fsize);
-  argv[i++] = "-a";
-  argv[i++] = g_strdup_printf ("%d", xpos);
-  argv[i++] = "-b";
-  argv[i++] = g_strdup_printf ("%d", ypos);
+  argv[argc++] = g_get_prgname ();
+  argv[argc++] = "-x";
+  argv[argc++] = g_strdup_printf ("%d", xsize);
+  argv[argc++] = "-y";
+  argv[argc++] = g_strdup_printf ("%d", ysize);
+  argv[argc++] = "-n";
+  argv[argc++] = g_strdup_printf ("%d", nmines);
+  argv[argc++] = "-f";
+  argv[argc++] = g_strdup_printf ("%d", fsize);
+  argv[argc++] = "-a";
+  argv[argc++] = g_strdup_printf ("%d", xpos);
+  argv[argc++] = "-b";
+  argv[argc++] = g_strdup_printf ("%d", ypos);
 
-  gnome_client_set_restart_command (client, i, argv);
-  /* i.e. clone_command = restart_command - '--sm-client-id' */
-  gnome_client_set_clone_command (client, 0, NULL);
+  egg_sm_client_set_restart_command (client, argc, (const char **) argv);
 
-  for (j = 2; j < i; j += 2)
+  for (j = 2; j < argc; j += 2)
     g_free (argv[j]);
 
   return TRUE;
 }
-
 
+static gint
+quit_cb (EggSMClient *client,
+         gpointer client_data)
+{
+  gtk_main_quit ();
+
+  return FALSE;
+}
+
+#endif /* WITH_SMCLIENT */
 
 static int xpos = -1, ypos = -1;
 
@@ -943,7 +960,6 @@ sound_init (int *argcp, char **argvp[])
 int
 main (int argc, char *argv[])
 {
-  GnomeProgram *program;
   GOptionContext *context;
 
   GtkWidget *all_boxes;
@@ -952,9 +968,13 @@ main (int argc, char *argv[])
   GtkWidget *box;
   GtkWidget *label;
   GtkWidget *face_box;
-  GnomeClient *client;
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;
+  gboolean retval;
+  GError *error = NULL;
+#ifdef WITH_SMCLIENT
+  EggSMClient *sm_client;
+#endif /* WITH_SMCLIENT */
 
   static const GOptionEntry options[] = {
     {"width", 'x', 0, G_OPTION_ARG_INT, &xsize, N_("Width of grid"), N_("X")},
@@ -971,19 +991,41 @@ main (int argc, char *argv[])
     {NULL}
   };
 
+#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
+  /* If we're going to use gnome-vfs, we need to init threads before
+   * calling any glib functions.
+   */
+  g_thread_init (NULL);
+#endif
+
+  if (!games_runtime_init ("gnomine"))
+    return 1;
+
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  context = g_option_context_new ("");
+  context = g_option_context_new (NULL);
+#if GLIB_CHECK_VERSION (2, 12, 0)
+  g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+#ifdef WITH_SMCLIENT
+  g_option_context_add_group (context, egg_sm_client_get_option_group ());
+#endif /* WITH_SMCLIENT */
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
-  program = gnome_program_init (APP_NAME, VERSION, LIBGNOMEUI_MODULE,
-				argc, argv,
-				GNOME_PARAM_APP_DATADIR, DATADIR,
-				GNOME_PARAM_GOPTION_CONTEXT, context, NULL);
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
+  if (!retval) {
+    g_print ("%s", error->message);
+    g_error_free (error);
+    exit (1);
+  }
+
+  g_set_application_name (_(APP_NAME_LONG));
     
   games_conf_initialise (APP_NAME);
 
@@ -995,9 +1037,15 @@ main (int argc, char *argv[])
                     G_CALLBACK (conf_value_changed_cb), NULL);
 
   gtk_window_set_default_icon_name ("gnome-mines");
-  client = gnome_master_client ();
-  g_signal_connect (G_OBJECT (client), "save_yourself",
-		    G_CALLBACK (save_state), argv[0]);
+
+#ifdef WITH_SMCLIENT
+  sm_client = egg_sm_client_get ();
+  g_signal_connect (sm_client, "save-state",
+		    G_CALLBACK (save_state_cb), NULL);
+  g_signal_connect (sm_client, "quit",
+                    G_CALLBACK (quit_cb), NULL);
+#endif /* WITH_SMCLIENT */
+
 
   if (xsize == -1)
     xsize = games_conf_get_integer (KEY_GEOMETRY_GROUP, KEY_XSIZE, NULL);
@@ -1021,7 +1069,8 @@ main (int argc, char *argv[])
   gtk_rc_parse_string
     ("style \"gnomine\" { GtkButton::interior-focus = 0 } class \"GtkButton\" style \"gnomine\"");
 
-  window = gnome_app_new (APP_NAME, APP_NAME_LONG);
+  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title (GTK_WINDOW (window), _(APP_NAME_LONG));
     
   games_conf_add_window (GTK_WINDOW (window), NULL);
 
@@ -1038,7 +1087,8 @@ main (int argc, char *argv[])
 
   all_boxes = gtk_vbox_new (FALSE, 0);
 
-  gnome_app_set_contents (GNOME_APP (window), all_boxes);
+  gtk_container_add (GTK_CONTAINER (window), all_boxes);
+
   ui_manager = create_ui_manager ("GnomineActions");
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
@@ -1059,11 +1109,11 @@ main (int argc, char *argv[])
   face_box = gtk_vbox_new (FALSE, 5);
   gtk_container_add (GTK_CONTAINER (mbutton), face_box);
 
-  pm_win = image_widget_setup ("gnomine/face-win.svg");
-  pm_sad = image_widget_setup ("gnomine/face-sad.svg");
-  pm_smile = image_widget_setup ("gnomine/face-smile.svg");
-  pm_cool = image_widget_setup ("gnomine/face-cool.svg");
-  pm_worried = image_widget_setup ("gnomine/face-worried.svg");
+  pm_win = image_widget_setup ("face-win.svg");
+  pm_sad = image_widget_setup ("face-sad.svg");
+  pm_smile = image_widget_setup ("face-smile.svg");
+  pm_cool = image_widget_setup ("face-cool.svg");
+  pm_worried = image_widget_setup ("face-worried.svg");
 
   gtk_box_pack_start (GTK_BOX (face_box), pm_win, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (face_box), pm_sad, FALSE, FALSE, 0);
@@ -1115,7 +1165,7 @@ main (int argc, char *argv[])
   gtk_box_pack_start (GTK_BOX (box), gtk_hseparator_new (), FALSE, FALSE, 0);
 
   status_box = gtk_hbox_new (TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (box), status_box, FALSE, FALSE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (box), status_box, FALSE, FALSE, 8);
 
   flabel = gtk_label_new ("");
   gtk_box_pack_start (GTK_BOX (status_box), flabel, FALSE, FALSE, 0);
@@ -1151,9 +1201,7 @@ main (int argc, char *argv[])
     
   games_conf_shutdown ();
 
-  gnome_accelerators_sync ();
-
-  g_object_unref (program);
+  games_runtime_shutdown ();
 
   return 0;
 }
