@@ -27,18 +27,20 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <games-clock.h>
-#include <games-stock.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
-#include <games-conf.h>
+#include <libgames-support/games-clock.h>
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-stock.h>
 
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif /* HAVE_GNOME */
+#ifdef WITH_SMCLIENT
+#include <libgames-support/eggsmclient.h>
+#endif /* WITH_SMCLIENT */
 
 #define APPNAME "gnotravex"
 #define APPNAME_LONG N_("Tetravex")
@@ -68,7 +70,6 @@ N_("8"), N_("9") };
 static GtkWidget *window;
 static GtkWidget *statusbar;
 static GtkWidget *space;
-static GtkWidget *bit;
 static GtkWidget *timer;
 static GdkGC *bg_gc;
 
@@ -122,10 +123,8 @@ static gint game_state = gameover;
 static gint have_been_hinted = 0;
 static gint solve_me = 0;
 static gint hint_moving = 0;
-static gint session_flag = 0;
 static gint session_xpos = 0;
 static gint session_ypos = 0;
-static gint session_position = 0;
 static guint timer_timeout = 0;
 static gint tile_size = 0;
 static gdouble tile_border_size = 3.0;
@@ -218,15 +217,14 @@ gint button_motion_space (GtkWidget *, GdkEventButton *);
 
 void gui_build_vertices (void);
 void gui_draw_faces (cairo_t * context, gint xadd, gint yadd, int quads[][7],
-		     int count, guint colours[4], gboolean prelight);
+                     int count, guint colours[4], gboolean prelight);
 void gui_draw_arrow (GdkPixmap * target);
 void gui_draw_socket (GdkPixmap * target, GtkStateType state, gint xadd,
-		      gint yadd);
+                      gint yadd);
 void gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number, gdouble *colour);
 void gui_draw_tile (GdkPixmap * target, GtkStateType state, gint xadd,
-		    gint yadd, gint north, gint south, gint east, gint west, gboolean prelight);
+                    gint yadd, gint north, gint south, gint east, gint west, gboolean prelight);
 void gui_draw_pixmap (GdkPixmap *, gint, gint, gboolean);
-void gui_draw_pause (void);
 
 void get_pixeltilexy (gint, gint, gint *, gint *);
 void get_tilexy (gint, gint, gint *, gint *);
@@ -257,14 +255,15 @@ void clickmove_toggle_cb (GtkToggleAction *, gpointer);
 void hint_move (gint, gint, gint, gint);
 gint show_score_dialog (gint, gboolean);
 void new_game (void);
-#ifdef HAVE_GNOME
-static gint save_state (GnomeClient *, gint, GnomeRestartStyle,
-			gint, GnomeInteractStyle, gint, gpointer);
-#endif                     
+
+#ifdef WITH_SMCLIENT
+static int save_state_cb (EggSMClient *client, GKeyFile *keyfile, gpointer client_data);
+static int quit_cb (EggSMClient *client, gpointer client_data);
+#endif /* WITH_SMCLIENT */
 static void set_fullscreen_actions (gboolean is_fullscreen);
 static void fullscreen_cb (GtkAction * action);
 static gboolean window_state_cb (GtkWidget * widget, GdkEventWindowState * event);
-static void load_pixmaps (void);
+static void load_default_background (void);
 
 static GtkAction *new_game_action;
 static GtkAction *pause_action;
@@ -411,13 +410,11 @@ main (int argc, char **argv)
   GtkWidget *menubar;
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;
-#ifdef HAVE_GNOME
-  GnomeClient *client;
-  GnomeProgram *program;
-#else
   gboolean retval;
   GError *error = NULL;
-#endif
+#ifdef WITH_SMCLIENT
+  EggSMClient *sm_client;
+#endif /* WITH_SMCLIENT */
 
 #if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
   /* If we're going to use gnome-vfs, we need to init threads before
@@ -426,39 +423,33 @@ main (int argc, char **argv)
   g_thread_init (NULL);
 #endif
 
+  if (!games_runtime_init ("gnotravex"))
+    return 1;
+
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
   context = g_option_context_new (NULL);
-  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-
-#ifdef HAVE_GNOME
-  program = gnome_program_init (APPNAME, VERSION,
-				LIBGNOMEUI_MODULE,
-				argc, argv,
-				GNOME_PARAM_GOPTION_CONTEXT, context,
-				GNOME_PARAM_APP_DATADIR, DATADIR,
-                                NULL);
-  
-  client = gnome_master_client ();
-  g_signal_connect (client, "save_yourself",
-                    G_CALLBACK (save_state), argv[0]);
-  g_signal_connect (client, "die",
-                    G_CALLBACK (quit_game_cb), argv[0]);
-#else
+#if GLIB_CHECK_VERSION (2, 12, 0)
+  g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif /* GLIB_CHECK_VERSION (2, 12, 0) */
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
+#ifdef WITH_SMCLIENT
+  g_option_context_add_group (context, egg_sm_client_get_option_group ());
+#endif /* WITH_SMCLIENT */
 
+  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
   retval = g_option_context_parse (context, &argc, &argv, &error);
+
   g_option_context_free (context);
   if (!retval) {
     g_print ("%s", error->message);
     g_error_free (error);
     exit (1);
   }
-#endif /* HAVE_GNOME */
 
   g_set_application_name (_(APPNAME_LONG));
 
@@ -470,6 +461,14 @@ main (int argc, char **argv)
 
   gtk_window_set_default_icon_name ("gnome-tetravex");
 
+#ifdef WITH_SMCLIENT
+  sm_client = egg_sm_client_get ();
+  g_signal_connect (sm_client, "save-state",
+                    G_CALLBACK (save_state_cb), NULL);
+  g_signal_connect (sm_client, "quit",
+                    G_CALLBACK (quit_cb), NULL);
+#endif /* WITH_SMCLIENT */
+
   if (size == -1)
     size = games_conf_get_integer (NULL, KEY_GRID_SIZE, NULL);
   if (size < 2 || size > 6)
@@ -479,7 +478,7 @@ main (int argc, char **argv)
   coloured_tiles = games_conf_get_boolean (NULL, KEY_SHOW_COLOURS, NULL);
   click_to_move = games_conf_get_boolean (NULL, KEY_CLICK_MOVE, NULL);
 
-  load_pixmaps ();
+  load_default_background ();
   create_window ();
 
   space = gtk_drawing_area_new ();
@@ -510,15 +509,15 @@ main (int argc, char **argv)
   gdk_gc_set_fill (bg_gc, GDK_TILED);
 
   g_signal_connect (G_OBJECT (space), "expose_event",
-		    G_CALLBACK (expose_space), NULL);
+                    G_CALLBACK (expose_space), NULL);
   g_signal_connect (G_OBJECT (space), "configure_event",
-		    G_CALLBACK (configure_space), NULL);
+                    G_CALLBACK (configure_space), NULL);
   g_signal_connect (G_OBJECT (space), "button_press_event",
-		    G_CALLBACK (button_press_space), NULL);
+                    G_CALLBACK (button_press_space), NULL);
   g_signal_connect (G_OBJECT (space), "button_release_event",
-		    G_CALLBACK (button_release_space), NULL);
+                    G_CALLBACK (button_release_space), NULL);
   g_signal_connect (G_OBJECT (space), "motion_notify_event",
-		    G_CALLBACK (button_motion_space), NULL);
+                    G_CALLBACK (button_motion_space), NULL);
   /* We do our own double-buffering. */
   gtk_widget_set_double_buffered (space, FALSE);
 
@@ -539,9 +538,7 @@ main (int argc, char **argv)
 
   games_conf_shutdown ();
 
-#ifdef HAVE_GNOME
-  g_object_unref (program);
-#endif /* HAVE_GNOME */
+  games_runtime_shutdown ();
 
   return 0;
 }
@@ -580,7 +577,7 @@ update_move_menu_sensitivity (void)
       s = FALSE;
     for (y = 0; y < size; y++)
       if (tiles[x][y].status == USED)
-	clear = FALSE;
+        clear = FALSE;
   }
 
   if (clear || (game_state == paused))
@@ -606,20 +603,19 @@ create_window (void)
 
   gtk_widget_realize (window);
   g_signal_connect (G_OBJECT (window), "delete_event",
-		    G_CALLBACK (quit_game_cb), NULL);
+                    G_CALLBACK (quit_game_cb), NULL);
   g_signal_connect (G_OBJECT (window), "window_state_event",
-		    G_CALLBACK (window_state_cb), NULL);
-
+                    G_CALLBACK (window_state_cb), NULL);
 }
 
 gint
 expose_space (GtkWidget * widget, GdkEventExpose * event)
 {
   gdk_draw_drawable (widget->window,
-		     widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
-		     buffer, event->area.x, event->area.y,
-		     event->area.x, event->area.y,
-		     event->area.width, event->area.height);
+                     widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
+                     buffer, event->area.x, event->area.y,
+                     event->area.x, event->area.y,
+                     event->area.width, event->area.height);
   return FALSE;
 }
 
@@ -646,9 +642,9 @@ button_press_space (GtkWidget * widget, GdkEventButton * event)
       return FALSE;
     }
     else
-    {	       
+    {
       if (setup_mover (event->x, event->y, PRESS))
-	button_down = 1;
+        button_down = 1;
     }
   }
   else
@@ -781,7 +777,7 @@ gui_build_vertices (void)
 
 void
 gui_draw_faces (cairo_t * context, gint xadd, gint yadd, int quads[][7],
-		int count, guint colours[4], gboolean prelight)
+                int count, guint colours[4], gboolean prelight)
 {
   int i, j, k;
   int *quad;
@@ -799,7 +795,7 @@ gui_draw_faces (cairo_t * context, gint xadd, gint yadd, int quads[][7],
     n_vertices = quad[2];
     colour = tile_colours[colours[face]][level];
     cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0,
-			   colour[2] / 255.0, colour[3] / 255.0);
+                           colour[2] / 255.0, colour[3] / 255.0);
 
     k = quad[3];
     cairo_move_to (context, xadd + vertices[k][0], yadd + vertices[k][1]);
@@ -837,7 +833,7 @@ gui_draw_socket (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd)
   gdouble *colour;
   
   gdk_draw_rectangle (GDK_DRAWABLE(target), bg_gc, TRUE, xadd, yadd, 
-		      tile_size, tile_size);
+                      tile_size, tile_size);
 
   context = gdk_cairo_create (GDK_DRAWABLE (target));
 
@@ -871,7 +867,7 @@ gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number, gdouble
   text = _(translatable_number[number]);
 
   cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0,
-			 colour[2] / 255.0, colour[3] / 255.0);
+                         colour[2] / 255.0, colour[3] / 255.0);
 
   cairo_text_extents (context, text, &extents);
   cairo_move_to (context, x - extents.width / 2.0, y + extents.height / 2.0);
@@ -880,7 +876,7 @@ gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number, gdouble
 
 void
 gui_draw_tile (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd,
-	       gint north, gint south, gint east, gint west, gboolean prelight)
+               gint north, gint south, gint east, gint west, gboolean prelight)
 {
   cairo_t *context;
   guint colours[4];
@@ -916,11 +912,11 @@ gui_draw_tile (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd,
   cairo_set_line_width (context, 1.0);
   cairo_set_source_rgba (context, 0.0, 0.0, 0.0, 1.0);
   cairo_rectangle (context, xadd + 0.5, yadd + 0.5, tile_size - 1.0,
-		   tile_size - 1.0);
+                   tile_size - 1.0);
   cairo_stroke (context);
 
   cairo_select_font_face (context, "Sans", CAIRO_FONT_SLANT_NORMAL,
-			  CAIRO_FONT_WEIGHT_BOLD);
+                          CAIRO_FONT_WEIGHT_BOLD);
   cairo_set_font_size (context, tile_size / 3.5);
 
   gui_draw_number (context, xadd + tile_size / 2, yadd + tile_size / 5, north, tile_colours[colours[NORTH]][TEXT]);
@@ -951,10 +947,10 @@ button_motion_space (GtkWidget * widget, GdkEventButton * event)
     get_tilexy (event->x, event->y, &x, &y);
     if ((x != oldx) || (y != oldy)) {
       if ((oldx != -1) && (tiles[oldy][oldx].status == USED)) {
-	 gui_draw_pixmap (buffer, oldx, oldy, FALSE);
+        gui_draw_pixmap (buffer, oldx, oldy, FALSE);
       }
       if ((x != -1) && (tiles[y][x].status == USED)) {
-	gui_draw_pixmap (buffer, x, y, TRUE);
+        gui_draw_pixmap (buffer, x, y, TRUE);
       }
       oldx = x;
       oldy = y;
@@ -987,9 +983,13 @@ gui_draw_pixmap (GdkPixmap * target, gint x, gint y, gboolean prelight)
   if (prelight)
     state = GTK_STATE_PRELIGHT;
 
-  if (which == USED)
-    gui_draw_tile (target, state, xadd, yadd, tiles[y][x].n, tiles[y][x].s,
-		   tiles[y][x].e, tiles[y][x].w, state);
+  if (which == USED) {
+    if (game_state == paused)
+      gui_draw_tile (buffer, GTK_STATE_NORMAL, xadd, yadd, 0, 0, 0, 0, FALSE);    
+    else
+      gui_draw_tile (target, state, xadd, yadd, tiles[y][x].n, tiles[y][x].s,
+                     tiles[y][x].e, tiles[y][x].w, state);
+  }
   else
     gui_draw_socket (target, state, xadd, yadd);
 
@@ -1071,9 +1071,9 @@ setup_mover (gint x, gint y, gint status)
   if (status == PRESS) {
     get_tilexy (x, y, &xx, &yy);
     if (xx == -1)
-      return 0;			/* No move */
+      return 0; /* No move */
     if (tiles[yy][xx].status == UNUSED)
-      return 0;			/* No move */
+      return 0; /* No move */
     get_offsetxy (x, y, &mover.xoff, &mover.yoff);
 
     mover.xstart = xx;
@@ -1093,10 +1093,10 @@ setup_mover (gint x, gint y, gint status)
 
   if (status == RELEASE) {
     get_tilexy_lazy (x - mover.xoff + tile_size / 2,
-		     y - mover.yoff + tile_size / 2, &xx, &yy);
+                     y - mover.yoff + tile_size / 2, &xx, &yy);
     if (tiles[yy][xx].status == UNUSED
-	&& xx >= 0 && xx < size * 2
-	&& yy >= 0 && yy < size && valid_drop (xx, yy)) {
+        && xx >= 0 && xx < size * 2
+        && yy >= 0 && yy < size && valid_drop (xx, yy)) {
       tiles[yy][xx] = tiles[mover.ystart][mover.xstart];
       tiles[yy][xx].status = USED;
       gui_draw_pixmap (buffer, xx, yy, FALSE);
@@ -1114,9 +1114,9 @@ setup_mover (gint x, gint y, gint status)
       games_clock_stop (GAMES_CLOCK (timer));
       set_game_menu_items_sensitive (FALSE);
       if (!have_been_hinted) {
-	message (_("Puzzle solved! Well done!"));
+        message (_("Puzzle solved! Well done!"));
       } else {
-	message (_("Puzzle solved!"));
+        message (_("Puzzle solved!"));
       }
       game_score ();
     }
@@ -1171,37 +1171,37 @@ move_column (unsigned char dir)
   case 'n':
     for (x = 0; x < size; x++)
       if (tiles[0][x].status == USED)
-	return;
+        return;
     for (y = 1; y < size; y++)
       for (x = 0; x < size; x++)
-	move_tile (x, y - 1, x, y);
+        move_tile (x, y - 1, x, y);
     redraw_left ();
     break;
   case 's':
     for (x = 0; x < size; x++)
       if (tiles[size - 1][x].status == USED)
-	return;
+        return;
     for (y = size - 2; y >= 0; y--)
       for (x = 0; x < size; x++)
-	move_tile (x, y + 1, x, y);
+        move_tile (x, y + 1, x, y);
     redraw_left ();
     break;
   case 'w':
     for (y = 0; y < size; y++)
       if (tiles[y][0].status == USED)
-	return;
+        return;
     for (y = 0; y < size; y++)
       for (x = 1; x < size; x++)
-	move_tile (x - 1, y, x, y);
+        move_tile (x - 1, y, x, y);
     redraw_left ();
     break;
   case 'e':
     for (y = 0; y < size; y++)
       if (tiles[y][size - 1].status == USED)
-	return;
+        return;
     for (y = 0; y < size; y++)
       for (x = size - 2; x >= 0; x--)
-	move_tile (x + 1, y, x, y);
+        move_tile (x + 1, y, x, y);
     redraw_left ();
     break;
   default:
@@ -1217,7 +1217,7 @@ game_over (void)
   for (y = 0; y < size; y++)
     for (x = 0; x < size; x++)
       if (tiles[y][x].status == UNUSED)
-	return 0;
+        return 0;
 
   return 1;
 }
@@ -1232,25 +1232,25 @@ show_score_dialog (gint pos, gboolean endofgame)
   if (!scoresdialog) {
     scoresdialog = games_scores_dialog_new (GTK_WINDOW (window), highscores, _("Tetravex Scores"));
     games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
-						  (scoresdialog), _("Size:"));
+                                                  (scoresdialog), _("Size:"));
   }
   if (pos > 0) {
     games_scores_dialog_set_hilight (GAMES_SCORES_DIALOG (scoresdialog), pos);
     message = g_strdup_printf ("<b>%s</b>\n\n%s",
-			       _("Congratulations!"),
-			       _("Your score has made the top ten."));
+                               _("Congratulations!"),
+                               _("Your score has made the top ten."));
     games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
-				     message);
+                                     message);
     g_free (message);
   } else {
     games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
-				     NULL);
+                                     NULL);
   }
 
   if (endofgame) {
     games_scores_dialog_set_buttons (GAMES_SCORES_DIALOG (scoresdialog),
-				     GAMES_SCORES_QUIT_BUTTON |
-				     GAMES_SCORES_NEW_GAME_BUTTON);
+                                     GAMES_SCORES_QUIT_BUTTON |
+                                     GAMES_SCORES_NEW_GAME_BUTTON);
   } else {
     games_scores_dialog_set_buttons (GAMES_SCORES_DIALOG (scoresdialog), 0);
   }
@@ -1324,8 +1324,6 @@ configure_space (GtkWidget * widget, GdkEventConfigure * event)
   update_tile_size (event->width, event->height);
   make_buffer (widget);
   redraw_all ();
-  if (game_state == paused)
-    gui_draw_pause ();
   gtk_widget_thaw_child_notify (widget);
 
   return FALSE;
@@ -1349,7 +1347,7 @@ redraw_all (void)
   for (y = 0; y < size; y++)
     for (x = 0; x < size * 2; x++)
       gui_draw_pixmap (buffer, x, y, FALSE);
-   
+
   gui_draw_arrow(buffer);
 
   gdk_window_end_paint (space->window);
@@ -1423,7 +1421,7 @@ create_mover (void)
   attributes.visual = gdk_drawable_get_visual (space->window);
 
   mover.window = gdk_window_new (space->window, &attributes,
-				 (GDK_WA_VISUAL | GDK_WA_COLORMAP));
+                                 (GDK_WA_VISUAL | GDK_WA_COLORMAP));
   mover.pixmap = NULL;
 }
 
@@ -1499,7 +1497,7 @@ pause_game (void)
   if (game_state != paused) {
     game_state = paused;
     message (_("Game paused"));
-    gui_draw_pause ();
+    redraw_all ();
     update_move_menu_sensitivity ();
     gtk_action_set_sensitive (hint_action, FALSE);
     gtk_action_set_sensitive (solve_action, FALSE);
@@ -1534,40 +1532,6 @@ pause_cb (void)
   }
 }
 
-void
-gui_draw_pause (void)
-{
-  guint x, y, xadd, yadd, which;
-  GdkRegion *region;
-
-  if (!space->window)
-    return;
-
-  region = gdk_drawable_get_clip_region (GDK_DRAWABLE (space->window));
-  gdk_window_begin_paint_region (space->window, region);
-  gdk_draw_rectangle (space->window, bg_gc, TRUE, 0, 0, -1, -1);
-
-  for (y = 0; y < size; y++) {
-    for (x = 0; x < size * 2; x++) {
-      which = tiles[y][x].status;
-
-      xadd = x * tile_size + xborder + (x >= size) * gap;
-      yadd = y * tile_size + yborder;
-
-      if (which == USED)
-	gui_draw_tile (buffer, GTK_STATE_NORMAL, xadd, yadd, 0, 0, 0, 0, 
-		       FALSE);
-      else
-	gui_draw_socket (buffer, GTK_STATE_NORMAL, xadd, yadd);
-
-      gtk_widget_queue_draw_area (space, xadd, yadd, tile_size, tile_size);
-    }
-  }
-
-  gdk_window_end_paint (space->window);
-  gdk_region_destroy (region);
-}
-
 void
 timer_start (void)
 {
@@ -1588,10 +1552,10 @@ create_menu (GtkUIManager * ui_manager)
 
   gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
   gtk_action_group_add_actions (action_group, action_entry,
-				G_N_ELEMENTS (action_entry), window);
+                                G_N_ELEMENTS (action_entry), window);
   gtk_action_group_add_radio_actions (action_group, size_action_entry,
-				      G_N_ELEMENTS (size_action_entry), -1,
-				      G_CALLBACK (size_cb), NULL);
+                                      G_N_ELEMENTS (size_action_entry), -1,
+                                      G_CALLBACK (size_cb), NULL);
 
   gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
   gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL);
@@ -1614,7 +1578,7 @@ create_menu (GtkUIManager * ui_manager)
   set_fullscreen_actions (FALSE);
 
   gtk_action_group_add_toggle_actions (action_group, toggles,
-				       G_N_ELEMENTS (toggles), NULL);
+                                       G_N_ELEMENTS (toggles), NULL);
   action = gtk_action_group_get_action (action_group, "Colours");
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), coloured_tiles);
   action = gtk_action_group_get_action (action_group, "ClickToMove");
@@ -1636,7 +1600,7 @@ make_buffer (GtkWidget * widget)
     g_object_unref (buffer);
 
   buffer = gdk_pixmap_new (widget->window, widget->allocation.width,
-			   widget->allocation.height, -1);
+                           widget->allocation.height, -1);
 
 }
 
@@ -1644,18 +1608,27 @@ void
 new_game (){
   gchar *str;
 
+  /* Reset pause menu */
+  gtk_action_set_visible(pause_action, TRUE);
+  gtk_action_set_sensitive(pause_action, TRUE);
+  gtk_action_set_visible(resume_action, FALSE);
+  gtk_action_set_sensitive(resume_action, FALSE);
+
+  game_state = gameover;
+
   new_board (size);
   gtk_widget_freeze_child_notify (space);
   make_buffer (space);
   redraw_all ();
   gtk_widget_thaw_child_notify (space);
-  game_state = playing;
   timer_start ();
   set_game_menu_items_sensitive (TRUE);
   update_move_menu_sensitivity ();
   str = g_strdup_printf (_("Playing %d\303\227%d board"), size, size);
   message (str);
   g_free (str);
+    
+  game_state = playing;
 }
 
 void
@@ -1670,29 +1643,26 @@ quit_game_cb (void)
   gtk_main_quit ();
 }
 
-#ifdef HAVE_GNOME
-
-static gint
-save_state (GnomeClient * client, gint phase,
-	    GnomeRestartStyle save_style, gint shutdown,
-	    GnomeInteractStyle interact_style, gint fast,
-	    gpointer client_data)
+#ifdef WITH_SMCLIENT
+static int
+save_state_cb (EggSMClient *client,
+               GKeyFile* keyfile,
+               gpointer client_data)
 {
   gchar *argv[20];
-  gint i;
+  gint argc;
   gint xpos, ypos;
 
   gdk_window_get_origin (window->window, &xpos, &ypos);
 
-  i = 0;
-  argv[i++] = (char *) client_data;
-  argv[i++] = "-x";
-  argv[i++] = g_strdup_printf ("%d", xpos);
-  argv[i++] = "-y";
-  argv[i++] = g_strdup_printf ("%d", ypos);
+  argc = 0;
+  argv[argc++] = g_get_prgname ();
+  argv[argc++] = "-x";
+  argv[argc++] = g_strdup_printf ("%d", xpos);
+  argv[argc++] = "-y";
+  argv[argc++] = g_strdup_printf ("%d", ypos);
 
-  gnome_client_set_restart_command (client, i, argv);
-  gnome_client_set_clone_command (client, 0, NULL);
+  egg_sm_client_set_restart_command (client, argc, (const char **) argv);
 
   g_free (argv[2]);
   g_free (argv[4]);
@@ -1700,7 +1670,16 @@ save_state (GnomeClient * client, gint phase,
   return TRUE;
 }
 
-#endif /* HAVE_GNOME */
+static gint
+quit_cb (EggSMClient *client,
+         gpointer client_data)
+{
+  quit_game_cb ();
+
+  return FALSE;
+}
+
+#endif /* WITH_SMCLIENT */
 
 void
 size_cb (GtkAction * action, gpointer data)
@@ -1778,9 +1757,9 @@ find_first_tile (gint status, gint * xx, gint * yy)
   for (y = 0; y < size; y++)
     for (x = size; x < size * 2; x++)
       if (tiles[y][x].status == status) {
-	*xx = x;
-	*yy = y;
-	return;
+        *xx = x;
+        *yy = y;
+        return;
       }
 }
 
@@ -1798,7 +1777,7 @@ hint_move_cb (void)
   dy = (float) (hint_src_y - hint_dest_y) / COUNT;
   if (count <= COUNT) {
     gdk_window_move (mover.window, hint_src_x - (gint) (count * dx),
-		     (gint) hint_src_y - (gint) (count * dy));
+                     (gint) hint_src_y - (gint) (count * dy));
     count++;
   }
   if (count > COUNT) {
@@ -1844,15 +1823,15 @@ hint_cb (GtkAction * action, gpointer data)
   for (y = 0; y < size; y++)
     for (x = 0; x < size; x++)
       if (compare_tile (&hint_tile, &orig_tiles[y][x]) == 0) {
-	if (tiles[y][x].status == USED
-	    && compare_tile (&hint_tile, &tiles[y][x]) == 0) {
-	  /* Do Nothing */
-	} else {
-	  x2 = x;
-	  y2 = y;
-	  x = size;
-	  y = size;
-	}
+        if (tiles[y][x].status == USED
+            && compare_tile (&hint_tile, &tiles[y][x]) == 0) {
+        /* Do Nothing */
+        } else {
+          x2 = x;
+          y2 = y;
+          x = size;
+          y = size;
+        }
       }
 
   /* Tile I want to hint about is busy. Move the busy tile away! */
@@ -1907,11 +1886,7 @@ solve_cb (GtkAction * action, gpointer data)
 void
 help_cb (GtkAction * action, gpointer data)
 {
-#ifdef HAVE_GNOME
-  gnome_help_display ("gnotravex.xml", NULL, NULL);
-#else
-#warning need to port help to gtk-only!
-#endif /* HAVE_GNOME */
+  games_help_display (window, "gnotravex", NULL);
 }
 
 void
@@ -1927,20 +1902,20 @@ about_cb (GtkAction * action, gpointer data)
 #if GTK_CHECK_VERSION (2, 11, 0)
                          "program-name", _(APPNAME_LONG),
 #else
-			 "name", _(APPNAME_LONG),
+                         "name", _(APPNAME_LONG),
 #endif
-			 "version", VERSION,
-			 "comments",
-			 _("GNOME Tetravex is a simple puzzle where "
-			   "pieces must be positioned so that the "
-			   "same numbers are touching each other.\n\n"
-			   "Tetravex is a part of GNOME Games."),
-			 "copyright",
-			 "Copyright \xc2\xa9 1999-2007 Lars Rydlinge",
-			 "license", license,
+                         "version", VERSION,
+                         "comments",
+                         _("GNOME Tetravex is a simple puzzle where "
+                           "pieces must be positioned so that the "
+                           "same numbers are touching each other.\n\n"
+                           "Tetravex is a part of GNOME Games."),
+                         "copyright",
+                         "Copyright \xc2\xa9 1999-2008 Lars Rydlinge",
+                         "license", license,
                          "wrap-license", TRUE,
                          "authors", authors,
-			 "documenters", documenters,
+                         "documenters", documenters,
                          "translator-credits", _("translator-credits"),
                          "logo-icon-name", "gnome-tetravex",
                          "website", "http://www.gnome.org/projects/gnome-games",
@@ -1975,40 +1950,40 @@ window_state_cb (GtkWidget * widget, GdkEventWindowState * event)
 {
   if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
     set_fullscreen_actions (event->new_window_state &
-			    GDK_WINDOW_STATE_FULLSCREEN);
+                            GDK_WINDOW_STATE_FULLSCREEN);
     
   return FALSE;
 }
 
-static GdkPixmap *
-get_pixmap (const char *filename)
+static void
+load_default_background (void)
 {
-  GdkPixmap *ret;
-  GdkPixbuf *im;
+  GdkPixmap *pm;
+  GdkPixbuf *pb;
   char *path;
+  const char * dname; 
+  const char * filename = "baize.png";
   GError *error = NULL;
 
-  path = g_build_filename (PIXMAPDIR, filename, NULL);
-  im = gdk_pixbuf_new_from_file (path, &error);
-  if (im != NULL) {
-    gdk_pixbuf_render_pixmap_and_mask_for_colormap (im,
-						    gdk_colormap_get_system
-						    (), &ret, NULL, 127);
-    gdk_pixbuf_unref (im);
-  } else {
+  dname = games_runtime_get_directory (GAMES_RUNTIME_PIXMAP_DIRECTORY);
+  path = g_build_filename (dname, filename, NULL);
+  pb = gdk_pixbuf_new_from_file (path, &error);
+  if (pb == NULL) {
     g_warning ("Error loading file '%s': %s\n", path, error->message);
     g_error_free (error);
 
-    ret = NULL;
+    pb = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
+                         FALSE, 
+                         8,1,1);
+    gdk_pixbuf_fill (pb, 0xffffffff);
   }
+  gdk_pixbuf_render_pixmap_and_mask_for_colormap (pb,
+                                                  gdk_colormap_get_system (), 
+                                                  &pm, NULL, 127);
+  gdk_pixbuf_unref (pb);
   g_free (path);
 
-  return ret;
-}
+  default_background_pixmap = pm; 
 
-static void
-load_pixmaps (void)
-{
-  default_background_pixmap = get_pixmap ("baize.png");
 }
 
