@@ -27,8 +27,9 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 #include <config.h>
+
+#include <gtk/gtk.h>
 #include <gdk/gdk.h>
-#include <gnome.h>
 
 #include <stdio.h>
 
@@ -115,7 +116,7 @@ static gint gtk_tree_path_to_row (GtkTreePath *path)
   gint  row;
   if (sscanf (path_str, "%i", &row) != 1) {
     g_warning ("%s: could not convert '%s' to integer\n",
-	       G_GNUC_FUNCTION, path_str);
+	       G_STRFUNC, path_str);
     g_free (path_str);
     return -1;
   }
