@@ -56,9 +56,7 @@ void on_chat_window (void);
 void quit_game_cb (GtkWidget * widget, gpointer data);
 void undo_move_cb (GtkWidget * widget, gpointer data);
 void redo_move_cb (GtkWidget * widget, gpointer data);
-void black_level_cb (GtkWidget * widget, gpointer data);
-void white_level_cb (GtkWidget * widget, gpointer data);
-void about_cb (GtkWidget * widget, gpointer data);
+void about_cb (GtkAction * action, gpointer data);
 void comp_black_cb (GtkWidget * widget, gpointer data);
 void comp_white_cb (GtkWidget * widget, gpointer data);
 void quick_moves_cb (GtkWidget * widget, gpointer data);
