@@ -20,7 +20,6 @@
 #include <stdlib.h>
 #include <time.h>
 #include <dirent.h>
-#include <config.h>
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -29,13 +28,11 @@
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-frame.h>
+#include <libgames-support/games-help.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-scores-dialog.h>
-
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif /* HAVE_GNOME */
+#include <libgames-support/games-runtime.h>
     
 #include "mahjongg.h"
 #include "drawing.h"
@@ -154,7 +151,7 @@ mahjongg_theme_warning (gchar * message)
 				   GTK_BUTTONS_CLOSE,
 				   _("Could not load tile set"));
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-					    message);
+					    "%s", message);
 
   button = gtk_dialog_add_button (GTK_DIALOG (dialog),
 				  _("Preferences"), GTK_RESPONSE_ACCEPT);
@@ -554,7 +551,7 @@ fill_tile_menu (GtkWidget * menu)
   struct dirent *e;
   DIR *dir;
   gint itemno = 0;
-  gchar *dname = NULL;
+  const char *dname = NULL;
 
   if (tileset_list) {
     g_list_foreach (tileset_list, (GFunc) g_free, NULL);
@@ -563,11 +560,10 @@ fill_tile_menu (GtkWidget * menu)
 
   tileset_list = NULL;
 
-  dname = g_build_filename (PIXMAPDIR, NULL);
+  dname = games_runtime_get_directory(GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
   dir = opendir (dname);
 
   if (!dir) {
-    g_free (dname);
     return;
   }
 
@@ -598,7 +594,6 @@ fill_tile_menu (GtkWidget * menu)
   }
 
   closedir (dir);
-  g_free (dname);
 }
 
 static void
@@ -1263,11 +1258,7 @@ shuffle_tiles_callback (void)
 static void
 help_cb (GtkAction * action, gpointer data)
 {
-#ifdef HAVE_GNOME
-  gnome_help_display ("mahjongg.xml", NULL, NULL);
-#else
-#warning need to port help to gtk-only!
-#endif /* HAVE_GNOME */
+  games_help_display (window, APPNAME, NULL);
 }
 
 static const GtkActionEntry actions[] = {
@@ -1412,13 +1403,8 @@ main (int argc, char *argv[])
 
   GOptionContext *context;
 
-#ifdef HAVE_GNOME
-  GnomeClient *client;
-  GnomeProgram *program;
-#else
   gboolean retval;
   GError *error = NULL;
-#endif
 
 #if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
   /* If we're going to use gnome-vfs, we need to init threads before
@@ -1427,9 +1413,12 @@ main (int argc, char *argv[])
   g_thread_init (NULL);
 #endif
 
+  if (!games_runtime_init ("mahjongg"))
+    return 1;
+
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
@@ -1438,14 +1427,6 @@ main (int argc, char *argv[])
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 #endif
 
-#ifdef HAVE_GNOME
-  program = gnome_program_init (APPNAME, VERSION,
-				LIBGNOMEUI_MODULE,
-				argc, argv,
-                                GNOME_PARAM_GOPTION_CONTEXT, context,
-				GNOME_PARAM_APP_DATADIR, DATADIR,
-                                NULL);
-#else
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
@@ -1455,7 +1436,6 @@ main (int argc, char *argv[])
     g_error_free (error);
     exit (1);
   }
-#endif /* HAVE_GNOME */
 
   g_set_application_name (_(APPNAME_LONG));
 
@@ -1568,9 +1548,7 @@ main (int argc, char *argv[])
 
   games_conf_shutdown ();
 
-#ifdef HAVE_GNOME
-  g_object_unref (program);
-#endif /* HAVE_GNOME */
+  games_runtime_shutdown ();
 
   return 0;
 }
