@@ -11,17 +11,13 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-
 #include <gtk/gtk.h>
 
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif /* HAVE_GNOME */
-
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-gridframe.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-scores.h>
+#include <libgames-support/games-runtime.h>
 
 #include "same-gnome.h"
 
@@ -142,13 +138,8 @@ main (int argc, char *argv[])
     {NULL, '\0', 0, 0, NULL, NULL, NULL}
   };
 
-#ifdef HAVE_GNOME
-  GnomeClient *client;
-  GnomeProgram *program;
-#else
   gboolean retval;
   GError *error = NULL;
-#endif
 
 #if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
   /* If we're going to use gnome-vfs, we need to init threads before
@@ -157,12 +148,15 @@ main (int argc, char *argv[])
   g_thread_init (NULL);
 #endif
 
+  if (!games_runtime_init ("same-gnome"))
+    return 1;
+
   setgid_io_init ();
 
   /* Initialise i18n. */
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-  textdomain (GETTEXT_PACKAGE);
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
 
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
@@ -170,13 +164,6 @@ main (int argc, char *argv[])
 #endif
 
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-
-#ifdef HAVE_GNOME
-  program =
-    gnome_program_init (APPNAME, VERSION, LIBGNOMEUI_MODULE, argc, argv,
-			GNOME_PARAM_APP_DATADIR, DATADIR,
-			GNOME_PARAM_GOPTION_CONTEXT, context, NULL);
-#else
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
@@ -186,7 +173,6 @@ main (int argc, char *argv[])
     g_error_free (error);
     exit (1);
   }
-#endif /* HAVE_GNOME */
 
   g_set_application_name (_(APPNAME_LONG));
 
@@ -209,9 +195,7 @@ main (int argc, char *argv[])
 
   games_conf_shutdown ();
 
-#ifdef HAVE_GNOME
-  g_object_unref (program);
-#endif /* HAVE_GNOME */
+  games_runtime_shutdown ();
 
   return 0;
 }
